@@ -18,7 +18,7 @@
  * NOTE. This class should not be used directly. Use the
  *       "AddressBook" class instead.
  *
- * $Id: abook_local_file.php,v 1.17 2002/02/14 06:12:51 philippe_mingo Exp $
+ * $Id: abook_local_file.php,v 1.18.2.4 2002/10/15 22:10:38 jangliss Exp $
  */
 
 class abook_local_file extends addressbook_backend {
@@ -135,18 +135,28 @@ class abook_local_file extends addressbook_backend {
      * NOTE! Previous locks are broken by this function */
     function overwrite(&$rows) {
         $this->unlock();
-        $newfh = @fopen($this->filename, 'w');
+        $newfh = @fopen($this->filename . '.tmp', 'w');
         if(!$newfh) {
-            return $this->set_error("$file: " . _("Open failed"));
+            return $this->set_error($this->filename. '.tmp:' . _("Open failed"));
         }
         
         for($i = 0 ; $i < sizeof($rows) ; $i++) {
             if(is_array($rows[$i])) {
-                fwrite($newfh, join('|', $rows[$i]) . "\n");
+                for($j = 0 ; $j < count($rows[$i]) ; $j++) {
+                    $rows[$i][$j] = $this->quotevalue($rows[$i][$j]);
+                }
+                $tmpwrite = @fwrite($newfh, join('|', $rows[$i]) . "\n");
+                if ($tmpwrite == -1) {
+                    return $this->set_error($this->filename . '.tmp:' . _("Write failed"));
+                }
             }
         }       
 
         fclose($newfh);
+        if (!@copy($this->filename . '.tmp' , $this->filename)) {
+          return $this->set_error($this->filename.':' . _("Unable to update"));
+        }
+        @unlink($this->filename . '.tmp');
         $this->unlock();
         $this->open(true);
         return true;
@@ -247,9 +257,12 @@ class abook_local_file extends addressbook_backend {
         }
   
         /* Here is the data to write */
-        $data = $userdata['nickname'] . '|' . $userdata['firstname'] . '|' .
-                $userdata['lastname'] . '|' . $userdata['email'] . '|' .
-                $userdata['label'];
+        $data = $this->quotevalue($userdata['nickname']) . '|' .
+                $this->quotevalue($userdata['firstname']) . '|' .
+                $this->quotevalue($userdata['lastname']) . '|' .
+                $this->quotevalue($userdata['email']) . '|' .
+                $this->quotevalue($userdata['label']);
+
         /* Strip linefeeds */
         $data = ereg_replace("[\r\n]", ' ', $data);
         /* Add linefeed at end */
@@ -359,5 +372,15 @@ class abook_local_file extends addressbook_backend {
         return true;
     }
      
+    /* Function for quoting values before saving */
+    function quotevalue($value) {
+        /* Quote the field if it contains | or ". Double quotes need to
+         * be replaced with "" */
+        if(ereg("[|\"]", $value)) {
+            $value = '"' . str_replace('"', '""', $value) . '"';
+        }
+        return $value;
+    }
+
 } /* End of class abook_local_file */
-?>
\ No newline at end of file
+?>
