@@ -8,7 +8,7 @@
  *
  * This file provides the handling of often-used attachment types.
  *
- * $Id: attachment_common.php,v 1.10 2002/02/19 01:43:19 brong Exp $
+ * $Id: attachment_common.php,v 1.11.2.2 2002/10/02 05:47:56 jmunro Exp $
  */
 
 global $attachment_common_show_images_list;
@@ -28,6 +28,9 @@ $FileExtensionToMimeType = array('bmp'  => 'image/x-bitmap',
                                  'vcf'  => 'text/x-vcard');
 
 /* Register browser-supported image types */
+if (isset($_SESSION['attachment_common_types'])) {
+    $attachment_common_types = $_SESSION['attachment_common_types'];
+}
 if (isset($attachment_common_types)) {
     /* Don't run this before being logged in. That may happen
        when plugins include mime.php */
@@ -49,7 +52,7 @@ if (isset($attachment_common_types)) {
 }
 
 /* Register text-type attachments */
-register_attachment_common('message/rfc822', 'link_text');
+register_attachment_common('message/rfc822', 'link_message');
 register_attachment_common('text/plain',     'link_text');
 register_attachment_common('text/richtext',  'link_text');
 
@@ -104,7 +107,7 @@ function attachment_common_link_text(&$Args)
     /* The link that we created needs a name.  "view" will be displayed for
        all text attachments handled by this plugin. */
     $Args[1]['attachment_common']['text'] = _("view");
-    
+
     /* Each attachment has a filename on the left, which is a link.
        Where that link points to can be changed.  Just in case the link above
        for viewing text attachments is not the same as the default link for
@@ -117,6 +120,17 @@ function attachment_common_link_text(&$Args)
 }
 
 
+function attachment_common_link_message(&$Args)
+{
+    $Args[1]['attachment_common']['href'] = '../src/download.php?startMessage=' .
+        $Args[2] . '&amp;passed_id=' . $Args[3] . '&amp;mailbox=' . $Args[4] .
+        '&amp;passed_ent_id=' . $Args[5] . '&amp;override_type0=message&amp;override_type1=rfc822';
+    /* The link that we created needs a name.  "view" will be displayed for
+       all text attachments handled by this plugin. */
+    $Args[1]['attachment_common']['text'] = _("view");
+}
+
+
 function attachment_common_link_html(&$Args)
 {
     $Args[1]['attachment_common']['href'] = '../src/download.php?startMessage=' . 
