@@ -8,12 +8,12 @@
  *
  * Contains functions used to do authentication.
  *
- * $Id: auth.php,v 1.24 2002/04/06 21:00:18 graf25 Exp $
+ * $Id: auth.php,v 1.24.2.1 2002/10/08 17:15:56 jmunro Exp $
  */
 
 function is_logged_in() {
 
-    if ( session_is_registered('user_is_logged_in') ) {
+    if ( sqsession_is_registered('user_is_logged_in') ) {
         return;
     } else {
         include_once( '../functions/display_messages.php' );
@@ -22,4 +22,4 @@ function is_logged_in() {
     }
 }
 
-?>
\ No newline at end of file
+?>
