@@ -9,7 +9,7 @@
  * This contains all messages, including information, error, and just
  * about any other message you can think of.
  *
- * $Id: display_messages.php,v 1.48.2.1 2002/06/14 15:18:43 jmunro Exp $
+ * $Id: display_messages.php,v 1.48.2.2 2002/07/31 16:28:46 ullgren Exp $
  */
 
 /**
@@ -157,7 +157,7 @@ function logout_error( $errString, $errTitle = '' ) {
         $errTitle = $errString;
     }
     set_up_language($squirrelmail_language, true);
-    displayHtmlHeader( $errTitle );
+    displayHtmlHeader( $errTitle , '', FALSE);
     
     echo "<BODY TEXT=\"$color[8]\" BGCOLOR=\"$color[4]\" LINK=\"$color[7]\" VLINK=\"$color[7]\" ALINK=\"$color[7]\">\n\n" .
          '<CENTER>'.
