@@ -8,23 +8,21 @@
  *
  * This contains functions for manipulating user preferences in files
  *
- * $Id: file_prefs.php,v 1.5.2.1 2002/06/14 15:08:21 jmunro Exp $
+ * $Id: file_prefs.php,v 1.5.2.11 2002/10/29 21:34:36 kink Exp $
  */
 
-global $prefs_are_cached, $prefs_cache;
 
 /**
  * Check the preferences into the session cache.
  */
 function cachePrefValues($data_dir, $username) {
     global $prefs_are_cached, $prefs_cache;
-       
     if ( isset($prefs_are_cached) && $prefs_are_cached) {
         return;
     }
     
-    session_unregister('prefs_cache');
-    session_unregister('prefs_are_cached');
+    sqsession_unregister('prefs_cache');
+    sqsession_unregister('prefs_are_cached');
     
     /* Calculate the filename for the user's preference file */
     $filename = getHashedFile($username, $data_dir, "$username.pref");
@@ -39,8 +37,12 @@ function cachePrefValues($data_dir, $username) {
         logout_error( sprintf( _("Preference file, %s, does not exist. Log out, and log back in to create a default preference file."), $filename)  );
         exit;
     }
-
-    $file = fopen($filename, 'r');
+    /* Open the file, or else display an error to the user. */
+    if(!$file = @fopen($filename, 'r')) {
+        include_once( '../functions/display_messages.php' );
+        logout_error( sprintf( _("Preference file, %s, could not be opened. Contact your system administrator to resolve this issue."), $filename) );
+        exit;
+    }
 
     /* Read in the preferences. */
     $highlight_num = 0;
@@ -50,6 +52,7 @@ function cachePrefValues($data_dir, $username) {
         if ($equalsAt > 0) {
             $key = substr($pref, 0, $equalsAt);
             $value = substr($pref, $equalsAt + 1);
+            /* this is to 'rescue' old-style highlighting rules. */
             if (substr($key, 0, 9) == 'highlight') {
                 $key = 'highlight' . $highlight_num;
                 $highlight_num ++;
@@ -64,8 +67,8 @@ function cachePrefValues($data_dir, $username) {
 
     $prefs_are_cached = TRUE;
 
-    session_register('prefs_cache');
-    session_register('prefs_are_cached');
+    sqsession_register($prefs_cache, 'prefs_cache');
+    sqsession_register($prefs_are_cached, 'prefs_are_cached');
 }
    
 /**
@@ -94,13 +97,25 @@ function savePrefValues($data_dir, $username) {
    
     $filename = getHashedFile($username, $data_dir, "$username.pref");
 
-    $file = fopen($filename, 'w');
+    /* Open the file for writing, or else display an error to the user. */
+    if(!$file = @fopen($filename. '.tmp', 'w')) {
+        include_once( '../functions/display_messages.php' );
+        logout_error( sprintf( _("Preference file, %s, could not be opened. Contact your system administrator to resolve this issue."), "$filename.tmp") );
+        exit;
+    }
+
     foreach ($prefs_cache as $Key => $Value) {
         if (isset($Value)) {
-            fwrite($file, $Key . '=' . $Value . "\n");
+            $tmpwrite = @fwrite($file, $Key . '=' . $Value . "\n");
+            if ($tmpwrite == -1) {
+               logout_error( sprintf( _("Preference file, %s, could not be written. Contact your system administrator to resolve this issue.") , $filename . '.tmp') );
+               exit;
+            }
         }
     }
     fclose($file);
+    @copy($filename . '.tmp',$filename);
+    @unlink($filename . '.tmp');
     chmod($filename, 0600);
 }
 
@@ -115,7 +130,7 @@ function removePref($data_dir, $username, $string) {
     if (isset($prefs_cache[$string])) {
         unset($prefs_cache[$string]);
     }
- 
+
     savePrefValues($data_dir, $username);
 }
 
@@ -160,9 +175,9 @@ function checkForPrefs($data_dir, $username, $filename = '') {
 
         /* Otherwise, report an error. */
         $errTitle = sprintf( _("Error opening %s"), $default_pref );
-        if (!file_exists($default_pref)) {
+        if (!is_readable($default_pref)) {
             $errString = $errTitle . "<br>\n" .
-                         _("Default preference file not found!") . "<br>\n" .
+                         _("Default preference file not found or not readable!") . "<br>\n" .
                          _("Please contact your system administrator and report this error.") . "<br>\n";
             include_once( '../functions/display_messages.php' );
             logout_error( $errString, $errTitle );
@@ -189,20 +204,37 @@ function checkForPrefs($data_dir, $username, $filename = '') {
  */
 function setSig($data_dir, $username, $number, $value) {
     $filename = getHashedFile($username, $data_dir, "$username.si$number");
-    $file = fopen($filename, 'w');
-    fwrite($file, $value);
+    /* Open the file for writing, or else display an error to the user. */
+    if(!$file = @fopen("$filename.tmp", 'w')) {
+        include_once( '../functions/display_messages.php' );
+        logout_error( sprintf( _("Signature file, %s, could not be opened. Contact your system administrator to resolve this issue."), "$filename.tmp") );
+        exit;
+    }
+    $tmpwrite = @fwrite($file, $value);
+    if ($tmpwrite == -1) {
+       include_once( '../functions/display_messages.php' );
+       logout_error( sprintf( _("Signaute file, %s, could not be written. Contact your system administrator to resolve this issue.") , $filename . '.tmp'));
+       exit;
+    }
     fclose($file);
+    copy("$filename.tmp","$filename");
+    unlink("$filename.tmp");
 }
 
 /**
  * Get the signature.
  */
 function getSig($data_dir, $username, $number) {
-    #$filename = $data_dir . $username . '.si$number';
     $filename = getHashedFile($username, $data_dir, "$username.si$number");
     $sig = '';
     if (file_exists($filename)) {
         $file = fopen($filename, 'r');
+        /* Open the file, or else display an error to the user. */
+        if(!$file = @fopen($filename, 'r')) {
+            include_once( '../functions/display_messages.php' );
+            logout_error( sprintf( _("Signature file, %s, could not be opened. Contact your system administrator to resolve this issue."), $filename) );
+            exit;
+        }
         while (!feof($file)) {
             $sig .= fgets($file, 1024);
         }
