@@ -9,7 +9,7 @@
  * This contains the functions necessary to detect and decode MIME
  * messages.
  *
- * $Id: mime.php,v 1.189.2.3 2002/06/21 01:36:17 graf25 Exp $
+ * $Id: mime.php,v 1.189.2.14 2002/10/29 19:01:22 kink Exp $
  */
 
 require_once('../functions/imap.php');
@@ -496,14 +496,12 @@ function mime_fetch_body($imap_stream, $id, $ent_id ) {
         echo   '<tt><br>' .
                '<table width="80%"><tr>' .
                '<tr><td colspan=2>' .
-               _("Body retrieval error. The reason for this is most probably that the message is malformed. Please help us making future versions better by submitting this message to the developers knowledgebase!") .
-               " <A HREF=\"../src/retrievalerror.php?$par\"><br>" .
-               _("Submit message") . '</A><BR>&nbsp;' .
+               _("Body retrieval error. The reason for this is most probably that the message is malformed.") .
                '</td></tr>' .
-               '<td><b>' . _("Command:") . "</td><td>$cmd</td></tr>" .
-               '<td><b>' . _("Response:") . "</td><td>$response</td></tr>" .
-               '<td><b>' . _("Message:") . "</td><td>$message</td></tr>" .
-               '<td><b>' . _("FETCH line:") . "</td><td>$topline</td></tr>" .
+               '<tr><td><b>' . _("Command:") . "</td><td>$cmd</td></tr>" .
+               '<tr><td><b>' . _("Response:") . "</td><td>$response</td></tr>" .
+               '<tr><td><b>' . _("Message:") . "</td><td>$message</td></tr>" .
+               '<tr><td><b>' . _("FETCH line:") . "</td><td>$topline</td></tr>" .
                "</table><BR></tt></font><hr>";
 
         $data = sqimap_run_command ($imap_stream, "FETCH $passed_id BODY[]", true, $response, $message);
@@ -525,7 +523,7 @@ function mime_print_body_lines ($imap_stream, $id, $ent_id, $encoding) {
     // Don't kill the connection if the browser is over a dialup
     // and it would take over 30 seconds to download it.
 
-    // dont call set_time_limit in safe mode.
+    // don t call set_time_limit in safe mode.
     if (!ini_get("safe_mode")) {
         set_time_limit(0);
     }
@@ -755,8 +753,14 @@ function formatBody($imap_stream, $message, $color, $wrap_at) {
     // primary message. To add more of them, just put them in the
     // order that is their priority.
     global $startMessage, $username, $key, $imapServerAddress, $imapPort, $body,
-           $show_html_default, $has_unsafe_images, $view_unsafe_images, $sort;
+           $show_html_default, $has_unsafe_images, $sort;
 
+    if ( !check_php_version(4,1) ) {
+        global $_GET;
+    }
+    if(isset($_GET['view_unsafe_images'])) {
+        $view_unsafe_images = $_GET['view_unsafe_images'];
+    }
     $has_unsafe_images = 0;
 
     $id = $message->header->id;
@@ -776,7 +780,16 @@ function formatBody($imap_stream, $message, $color, $wrap_at) {
         // them here
         if ($body_message->header->type1 == 'html') {
             if ( $show_html_default <> 1 ) {
-                $body = strip_tags( $body );
+                $entity_conv = array('&nbsp;' => ' ',
+                                     '<p>'    => "\n\n",
+                                     '<br>'   => "\n",
+                                     '<P>'    => "\n",
+                                     '<BR>'   => "\n",
+                                     '&gt;'   => '>',
+                                     '&lt;'   => '<');
+                $body = strtr($body, $entity_conv);
+                $body = trim($body);
+                $body = strip_tags($body);
                 translateText($body, $wrap_at, $body_message->header->charset);
             } else {
                 $body = MagicHTML( $body, $id );
@@ -795,7 +808,7 @@ function formatBody($imap_stream, $message, $color, $wrap_at) {
         }
 
         /** Display the ATTACHMENTS: message if there's more than one part **/
-        if (isset($message->entities[1])) {
+        if (isset($message->entities[1]) || ($message->header->type0 == 'multipart')) {
             $body .= formatAttachments ($message, $ent_num, $message->header->mailbox, $id);
         }
     } else {
@@ -931,7 +944,7 @@ function formatAttachments($message, $ent_id, $mailbox, $id) {
             $DefaultLink =
                 "../src/download.php?startMessage=$startMessage&amp;passed_id=$id&amp;mailbox=$urlMailbox&amp;passed_ent_id=$ent";
             if ($where && $what) {
-	       $DefaultLink = '&amp;where='. urlencode($where).'&amp;what='.urlencode($what);
+	       $DefaultLink .= '&amp;where='. urlencode($where).'&amp;what='.urlencode($what);
             }
             $Links['download link']['text'] = _("download");
             $Links['download link']['href'] =
@@ -1547,13 +1560,13 @@ function sq_deent($attvalue){
      */
     if (strpos($attvalue, "#") !== false){
         $omit = Array(34, 39);
-        for ($asc=1; $asc<256; $asc++){
+        for ($asc=256; $asc>=0; $asc--){
             if (!in_array($asc, $omit)){
                 $chr = chr($asc);
-                $attvalue = preg_replace("/\&#0*$asc;*(\D)/si", "$chr\\1", 
-                                         $attvalue);
-                $attvalue = preg_replace("/\&#x0*".dechex($asc).";*(\W)/si",
-                                         "$chr\\1", $attvalue);
+                $octrule = '/\&#0*' . $asc . ';*/si';
+                $hexrule = '/\&#x0*' . dechex($asc) . ';*/si';
+                $attvalue = preg_replace($octrule, $chr, $attvalue);
+                $attvalue = preg_replace($hexrule, $chr, $attvalue);
             }
         }
     }
@@ -1951,14 +1964,18 @@ function magicHTML($body, $id){
                       "meta",
                       "html",
                       "head",
-                      "base"
+                      "base",
+                      "link",
+                      "frame",
+                      "iframe"
                       );
 
     $rm_tags_with_content = Array(
                                   "script",
                                   "applet",
                                   "embed",
-                                  "title"
+                                  "title",
+                                  "frameset"
                                   );
 
     $self_closing_tags =  Array(
@@ -1975,8 +1992,8 @@ function magicHTML($body, $id){
                          Array(
                                "/target/si",
                                "/^on.*/si",
-			       "/^dynsrc/si",
-			       "/^data.*/si"
+                               "/^dynsrc/si",
+                               "/^data.*/si"
                                )
                          );
 
@@ -1988,51 +2005,51 @@ function magicHTML($body, $id){
                     Array(
                           Array(
                                 "|^([\'\"])\s*\.\./.*([\'\"])|si",
-                                "/^([\'\"])\s*\S+script\s*:.*([\'\"])/si",
-				"/^([\'\"])\s*mocha\s*:*.*([\'\"])/si",
-				"/^([\'\"])\s*about\s*:.*([\'\"])/si"
+                                "/^([\'\"])\s*\S+\s*script\s*:.*([\'\"])/si",
+                                "/^([\'\"])\s*mocha\s*:*.*([\'\"])/si",
+                                "/^([\'\"])\s*about\s*:.*([\'\"])/si"
                                 ),
                           Array(
                                 "\\1$secremoveimg\\2",
                                 "\\1$secremoveimg\\2",
-				"\\1$secremoveimg\\2",
-				"\\1$secremoveimg\\2"
+                                "\\1$secremoveimg\\2",
+                                "\\1$secremoveimg\\2"
                                 )
                         ),
                 "/^href|action/i" =>
                     Array(
                           Array(
                                 "|^([\'\"])\s*\.\./.*([\'\"])|si",
-                                "/^([\'\"])\s*\S+script\s*:.*([\'\"])/si",
-				"/^([\'\"])\s*mocha\s*:*.*([\'\"])/si",
-				"/^([\'\"])\s*about\s*:.*([\'\"])/si"
+                                "/^([\'\"])\s*\S+\s*script\s*:.*([\'\"])/si",
+                                "/^([\'\"])\s*mocha\s*:*.*([\'\"])/si",
+                                "/^([\'\"])\s*about\s*:.*([\'\"])/si"
                                 ),
                           Array(
                                 "\\1#\\2",
                                 "\\1#\\2",
-				"\\1#\\2",
-				"\\1#\\2"
+                                "\\1#\\2",
+                                "\\1#\\2"
                                 )
                         ),
                 "/^style/si" =>
                     Array(
                           Array(
                                 "/expression/si",
-				"/binding/si",
-				"/behaviou*r/si",
+                                "/binding/si",
+                                "/behaviou*r/si",
                                 "|url\(([\'\"])\s*\.\./.*([\'\"])\)|si",
-                                "/url\(([\'\"])\s*\S+script\s*:.*([\'\"])\)/si",
-				"/url\(([\'\"])\s*mocha\s*:.*([\'\"])\)/si",
-				"/url\(([\'\"])\s*about\s*:.*([\'\"])\)/si"
+                                "/url\(([\'\"])\s*\S+\s*script\s*:.*([\'\"])\)/si",
+                                "/url\(([\'\"])\s*mocha\s*:.*([\'\"])\)/si",
+                                "/url\(([\'\"])\s*about\s*:.*([\'\"])\)/si"
                                ),
                           Array(
                                 "idiocy",
-				"idiocy",
-				"idiocy",
+                                "idiocy",
+                                "idiocy",
                                 "url(\\1#\\2)",
                                 "url(\\1#\\2)",
-				"url(\\1#\\2)",
-				"url(\\1#\\2)"
+                                "url(\\1#\\2)",
+                                "url(\\1#\\2)"
                                )
                           )
                 )
