@@ -8,7 +8,7 @@
  *
  * Functions needed to display the options pages.
  *
- * $Id: options.php,v 1.19 2002/02/02 02:17:05 philippe_mingo Exp $
+ * $Id: options.php,v 1.20.2.5 2002/10/29 19:01:23 kink Exp $
  */
 
 /**********************************************/
@@ -72,6 +72,7 @@ class SquirrelOption {
 
     function SquirrelOption
     ($name, $caption, $type, $refresh_level, $possible_values = '') {
+    global $_POST, $_GLOBALS; 
         /* Set the basic stuff. */
         $this->name = $name;
         $this->caption = $caption;
@@ -90,8 +91,8 @@ class SquirrelOption {
         }
 
         /* Check for a new value. */
-        if (isset($GLOBALS["new_$name"])) {
-            $this->new_value = $GLOBALS["new_$name"];
+        if (isset($_POST["new_$name"])) {
+            $this->new_value = $_POST["new_$name"];
         } else {
             $this->new_value = '';
         }
@@ -294,11 +295,15 @@ class SquirrelOption {
 }
 
 function save_option($option) {
-    global $data_dir, $username;
+    if ( !check_php_version(4,1) ) {
+        global $_SESSION;
+    }
+    global $data_dir;
+    $username = $_SESSION['username'];
     setPref($data_dir, $username, $option->name, $option->new_value);
 
     /* I do not know if this next line does any good. */
-    $GLOBALS[$option->name] = $option->new_value;
+//    $GLOBALS[$option->name] = $option->new_value;
 }
 
 function save_option_noop($option) {
@@ -389,10 +394,10 @@ function print_option_groups($option_groups) {
         if ($next_optgrp['name'] != '') {
             echo '<TR><TD ALIGN=CENTER VALIGN=MIDDLE COLSPAN=2 NOWRAP><B>'
                .   $next_optgrp['name']
-	       . "</B></TD></TR>\n";
-	}
-	
-	/* Print each option in this option group. */
+               . "</B></TD></TR>\n";
+        }
+
+        /* Print each option in this option group. */
         foreach ($next_optgrp['options'] as $option) {
             if ($option->type != SMOPT_TYPE_HIDDEN) {
                 echo "<TR>\n";
@@ -404,8 +409,8 @@ function print_option_groups($option_groups) {
                 echo $option->createHTMLWidget();
             }
         }
-	
-	/* Print an empty row after this option group. */
+
+        /* Print an empty row after this option group. */
         echo "<TR><TD COLSPAN=\"2\">&nbsp;</TD></TR>\n";
     }
 }
