@@ -8,19 +8,28 @@
  *
  * This contains functions for manipulating user preferences
  *
- * $Id: prefs.php,v 1.53 2002/02/04 12:53:26 simond Exp $
+ * $Id: prefs.php,v 1.54.2.3 2002/10/08 17:15:57 jmunro Exp $
  */
 
-global $prefs_are_cached, $prefs_cache;
+require_once('../src/global.php');
 
-if ( !session_is_registered('prefs_are_cached') ||
+if (isset($_SESSION['prefs_cache'])) {
+    $prefs_cache = $_SESSION['prefs_cache'];
+}
+if (isset($_SESSION['prefs_are_cached'])) {
+    $prefs_are_cached = $_SESSION['prefs_are_cached'];
+}
+
+$rg = ini_get('register_globals');
+if ( !sqsession_is_registered('prefs_are_cached') ||
      !isset( $prefs_cache) ||
      !is_array( $prefs_cache) ||
-     substr( phpversion(), 0, 3 ) == '4.1'  ) {
+     substr( phpversion(), 0, 3 ) == '4.1' ||
+     substr( phpversion(), 0, 3 ) == '4.2' ||
+     (substr( phpversion(), 0, 3 ) == '4.0' && empty($rg))) {
     $prefs_are_cached = false;
     $prefs_cache = array();
 }
-
 if (isset($prefs_dsn) && !empty($prefs_dsn)) {
     require_once('../functions/db_prefs.php');
 } else {
