@@ -6,11 +6,19 @@
  *  
  *  Philippe Mingo
  *  
- *  $Id: auth.php,v 1.6 2002/02/06 10:56:25 philippe_mingo Exp $
+ *  $Id: auth.php,v 1.7.2.3 2002/09/06 05:52:17 jmunro Exp $
  */
 function adm_check_user() {
-
-    GLOBAL $username, $PHP_SELF;
+    if ( (float)substr(PHP_VERSION,0,3) < 4.1) {
+        global $_SESSION, $_SERVER;
+    }
+    if (isset($_SESSION['username'])) {
+        $username = $_SESSION['username'];
+    }
+    else {
+        $username = "";
+    }
+    $PHP_SELF = $_SERVER['PHP_SELF'];
 
     if ( strpos( 'options.php', $PHP_SELF ) ) {
         $auth = FALSE;
@@ -24,6 +32,9 @@ function adm_check_user() {
         $adm = posix_getpwuid( $adm_id );
         $auth = ( $username == $adm['name'] );
     }
+    else {
+        $auth = FALSE;
+    }
 
     return( $auth );
 
