@@ -13,25 +13,17 @@
  *
  * This is a standard Squirrelmail-1.2 API for plugins.
  *
- * $Id: bug_report.php,v 1.6 2002/02/05 16:37:06 philippe_mingo Exp $
+ * $Id: bug_report.php,v 1.6.2.2 2002/08/31 03:17:41 jmunro Exp $
  */
 
 chdir('..');
 
-session_start();
+require_once('../src/validate.php');
 
-require_once('../config/config.php');
-require_once('../functions/strings.php');
-require_once('../functions/page_header.php');
-require_once('../functions/display_messages.php');
-require_once('../functions/imap.php');
-require_once('../functions/array.php');
-require_once('../functions/i18n.php');
-require_once('../src/load_prefs.php');
 displayPageHeader($color, 'None');
 
-
 function Show_Array($array) {
+    $str = "";
     foreach ($array as $key => $value) {
         if ($key != 0 || $value != '') {
         $str .= "    * $key = $value\n";
@@ -44,6 +36,7 @@ function Show_Array($array) {
 }
 
 $browser = get_browser();
+$body_top = "";
 $body_top .= "I subscribe to the squirrelmail-users mailing list.\n" .
                 "  [ ]  True - No need to CC me when replying\n" .
                 "  [ ]  False - Please CC me when replying\n" .
@@ -59,7 +52,7 @@ $body_top .= "I subscribe to the squirrelmail-users mailing list.\n" .
                 "(Optional) I got really bored and here's a fix:\n\n\n" .
                 "----------------------------------------------\n" .
             "\nMy browser information:\n" .
-            "  $HTTP_USER_AGENT\n" .
+            "  ".$_SERVER['HTTP_USER_AGENT'] ."\n" .
             "  get_browser() information (List)\n" .
             Show_Array((array) $browser) .
             "\nMy web server information:\n" .
@@ -70,7 +63,7 @@ $body_top .= "I subscribe to the squirrelmail-users mailing list.\n" .
             "  Version:  $version\n" .
             "  Plugins (List)\n" .
             Show_Array($plugins);
-if ($ldap_server[0] && ! extension_loaded('ldap')) {
+if (isset($ldap_server[0]) && $ldap_server[0] && ! extension_loaded('ldap')) {
     $warning = 1;
     $warnings['ldap'] = "LDAP server defined in SquirrelMail config, " .
         "but the module is not loaded in PHP";
@@ -80,6 +73,7 @@ if ($ldap_server[0] && ! extension_loaded('ldap')) {
     $corrections['ldap'][] = "Reconfigure SquirrelMail to not use LDAP";
 }
 
+$body = "";
 $body .= "\nMy IMAP server information:\n" .
             "  Server type:  $imap_server_type\n";
 $imap_stream = fsockopen ($imapServerAddress, $imapPort, $error_number, $error_string);
@@ -108,8 +102,9 @@ if ($imap_stream) {
     $corrections['imap'][] = "Make sure the server responds to port $imapPort";
 }
 
+$warning_html = "";
 $warning_num = 0;
-if ($warning) {
+if (isset($warning)) {
     foreach ($warnings as $key => $value) {
         if ($warning_num == 0) {
             $body_top .= "WARNINGS WERE REPORTED WITH YOUR SETUP:\n";
