@@ -10,7 +10,7 @@
  * Copyright (c) 1999-2002 The SquirrelMail Project Team
  * Licensed under the GNU GPL. For full terms see the file COPYING.
  *
- * $Id: setup.php,v 1.9 2002/05/14 18:37:57 jmunro Exp $
+ * $Id: setup.php,v 1.9.2.7 2002/10/29 19:01:26 kink Exp $
  */
 
 function squirrelmail_plugin_init_delete_move_next() {
@@ -103,13 +103,20 @@ function delete_move_expunge_from_all($id) {
 
 function delete_move_next_action() {
 
-    global $PHP_SELF,
-           $delete_id, $move_id;
-
-    if ($delete_id) {
+    global $PHP_SELF;
+    if ( !check_php_version(4,1) ) {
+        global $_GET, $_POST;
+    }
+    if (isset($_GET['delete_id'])) {
+        $delete_id = $_GET['delete_id'];
+    }
+    if (isset($_POST['move_id'])) {
+        $move_id = $_POST['move_id'];
+    }
+    if (isset($delete_id)) {
         delete_move_next_delete();
         fix_sort_array();
-    } elseif ($move_id) {
+    } elseif (isset($move_id)) {
         delete_move_next_move();
         fix_sort_array();
     }
@@ -207,8 +214,7 @@ function delete_move_next_read($currloc) {
 }
 
 function get_move_target_list() {
-    global $imapConnection;
-    
+    global $imapConnection, $lastTargetMailbox;
     $boxes = sqimap_mailbox_list($imapConnection);
     for ($i = 0; $i < count($boxes); $i++) {  
         if (!in_array('noselect', $boxes[$i]['flags'])) {
@@ -217,7 +223,12 @@ function get_move_target_list() {
             if ( $box2 == 'INBOX' ) {
                 $box2 = _("INBOX");
             }
-            echo "<option value=\"$box\">$box2</option>\n";
+            if ($box == $lastTargetMailbox) {
+                echo "<option value=\"$box\" SELECTED>$box2</option>\n";
+            }
+            else {
+                echo "<option value=\"$box\">$box2</option>\n";
+            }
         }
     }
 }
@@ -226,8 +237,17 @@ function delete_move_next_moveNextForm($next) {
 
     global $color, $where, $what, $currentArrayIndex, $passed_id,
            $urlMailbox, $sort, $startMessage, $delete_id, $move_id,
-           $imapConnection;
+           $imapConnection, $lastTargetMailbox;
 
+    if ( !check_php_version(4,1) ) {
+        global $_POST;
+    }
+            
+    if (isset($_POST['targetMailbox'])) {
+            $lastTargetMailbox = $_POST['targetMailbox'];
+            sqsession_unregister('lastTargetMailbox');
+            sqsession_register($lastTargetMailbox, 'lastTargetMailbox');
+    }
     echo '<tr>'.
          "<td bgcolor=\"$color[9]\" width=\"100%\" align=\"center\">".
            '<form action="read_body.php" method="post"><small>'.
@@ -275,8 +295,12 @@ function delete_move_next_moveRightMainForm() {
 
 
 function delete_move_next_delete() {
-    global $imapConnection, $delete_id, $mailbox, $auto_expunge;
-    
+    global $imapConnection, $auto_expunge;
+    if ( !check_php_version(4,1) ) {
+        global $_GET;
+    }
+    $delete_id = $_GET['delete_id'];
+    $mailbox = $_GET['mailbox'];
     sqimap_messages_delete($imapConnection, $delete_id, $delete_id, $mailbox);
     if ($auto_expunge){
         delete_move_expunge_from_all($delete_id);
@@ -285,8 +309,13 @@ function delete_move_next_delete() {
 }
 
 function delete_move_next_move() {
-    global $imapConnection, $move_id, $targetMailbox, $auto_expunge, $mailbox;
-    
+    global $imapConnection, $auto_expunge;
+    if ( !check_php_version(4,1) ) {
+        global $_POST;
+    }
+    $move_id = $_POST['move_id'];
+    $mailbox = $_POST['mailbox'];
+    $targetMailbox = $_POST['targetMailbox'];
     // Move message
     sqimap_messages_copy($imapConnection, $move_id, $move_id, $targetMailbox);
     sqimap_messages_flag($imapConnection, $move_id, $move_id, 'Deleted');
@@ -332,10 +361,22 @@ function delete_move_next_display_inside() {
 
 function delete_move_next_display_save() {
 
-    global $username,$data_dir,
-           $delete_move_next_ti, $delete_move_next_formATtopi,
-           $delete_move_next_bi, $delete_move_next_formATbottomi;
-    
+    global $username, $data_dir;
+    if ( !check_php_version(4,1) ) {
+        global $_POST;
+    }
+    if (isset($_POST['delete_move_next_ti'])) {
+        $delete_move_next_ti = $_POST['delete_move_next_ti'];
+    }
+    if (isset($_POST['delete_move_next_bi'])) {
+        $delete_move_next_bi = $_POST['delete_move_next_bi'];
+    }
+    if (isset($_POST['delete_move_next_formATtopi'])) {
+        $delete_move_next_formATtopi = $_POST['delete_move_next_formATtopi'];
+    }
+    if (isset($_POST['delete_move_next_formATbottomi'])) {
+        $delete_move_next_formATbottomi = $_POST['delete_move_next_formATbottomi'];
+    } 
     if (isset($delete_move_next_ti)) {
         setPref($data_dir, $username, 'delete_move_next_t', 'on');
     } else {
