@@ -22,7 +22,7 @@
  *
  * Also view plugins/README.plugins for more information.
  *
- * $Id: filters.php,v 1.31 2002/05/10 12:50:40 ondrass Exp $
+ * $Id: filters.php,v 1.31.2.3 2002/08/21 18:00:54 jmunro Exp $
  */
 
 function filters_SaveCache () {
@@ -245,9 +245,12 @@ function filters_sqimap_read_data ($imap_stream, $pre, $handle_errors, &$respons
 
 
 function start_filters() {
-    global $mailbox, $username, $key, $imapServerAddress, $imapPort, $imap,
+    global $mailbox, $imapServerAddress, $imapPort, $imap,
         $imap_general, $filters, $imap_stream, $imapConnection,
-    $UseSeparateImapConnection, $AllowSpamFilters;
+    $UseSeparateImapConnection, $AllowSpamFilters, $_SESSION, $_COOKIE;
+
+    $username = $_SESSION['username'];
+    $key = $_COOKIE['key'];
 
 #    if ($mailbox == 'INBOX') {
         // Detect if we have already connected to IMAP or not.
@@ -498,7 +501,7 @@ function spam_filters($imap_stream) {
     if ($SpamFilters_SharedCache) {
        filters_SaveCache();
     } else {
-       session_register('SpamFilters_DNScache');
+       sqsession_register($SpamFilters_DNScache, 'SpamFilters_DNScache');
     }
 }
 
