@@ -21,7 +21,7 @@
  *
  * Also view plugins/README.plugins for more information.
  *
- * $Id: setup.php,v 1.12 2002/02/10 15:43:47 philippe_mingo Exp $
+ * $Id: setup.php,v 1.20.2.4 2002/08/21 05:37:47 jmunro Exp $
  */
 
 /*
@@ -56,6 +56,15 @@ $AllowSpamFilters = true;
 global $SpamFilters_YourHop;
 $SpamFilters_YourHop = ' ';
 
+/*
+ * Some of the SPAM filters are COMMERCIAL and require a fee. If your users
+ * select them and you're not allowed to use them, it will make SPAM filtering
+ * very slow. If you don't want them to even be offered to the users, you
+ * should set SpamFilters_ShowCommercial to false.
+ */
+global $SpamFilters_ShowCommercial;
+$SpamFilters_ShowCommercial = false;
+
 /*
  * A cache of IPs we've already checked or are known bad boys or good boys
  * ie. $SpamFilters_DNScache["210.54.220.18"] = true;
@@ -65,18 +74,52 @@ $SpamFilters_YourHop = ' ';
  */
 global $SpamFilters_DNScache;
 
+/*
+ * Absolute path to the bulkquery program. Leave blank if you don't have
+ * bulkquery compiled, installed, and lwresd running. See the README file
+ * in the bulkquery directory for more information on using bulkquery.
+ */
+global $SpamFilters_BulkQuery;
+$SpamFilters_BulkQuery = "";
+
+/*
+ * Do you want to use a shared file for the DNS cache or a session variable?
+ * Using a shared file means that every user can benefit from any queries
+ * made by other users. The shared file is named "dnscache" and is in the
+ * data directory.
+ */
+global $SpamFilters_SharedCache;
+$SpamFilters_SharedCache = true;
+
+/*
+ * How long should DNS query results be cached for by default (in seconds)?
+ */
+global $SpamFilters_CacheTTL;
+$SpamFilters_CacheTTL = 7200;
+
 require_once ('../plugins/filters/filters.php');
 
 function squirrelmail_plugin_init_filters() {
     global $squirrelmail_plugin_hooks;
-    global $mailbox, $imap_stream, $imapConnection;
+
+    if (isset($_GET['mailbox'])) {
+        $mailbox = $_GET['mailbox'];
+    }
+    elseif (isset($_POST['mailbox'])) {
+        $mailbox = $_POST['mailbox'];
+    }
+    else {
+        $mailbox = 'INBOX';
+    }
 
     $squirrelmail_plugin_hooks['left_main_before']['filters'] = 'start_filters';
-    if ($mailbox == 'INBOX') {
+    if (isset($mailbox) && $mailbox == 'INBOX') {
         $squirrelmail_plugin_hooks['right_main_after_header']['filters'] = 'start_filters';
     }
-    $squirrelmail_plugin_hooks['optpage_register_block']['filters'] = 'squirrelmail_plugin_optpage_register_block';
-    $squirrelmail_plugin_hooks['special_mailbox']['filters'] = 'filters_special_mailbox';
+    $squirrelmail_plugin_hooks['optpage_register_block']['filters'] = 'filters_optpage_register_block';
+#    $squirrelmail_plugin_hooks['special_mailbox']['filters'] = 'filters_special_mailbox';
+    $squirrelmail_plugin_hooks['rename_or_delete_folder']['filters'] = 'update_for_folder';
+    $squirrelmail_plugin_hooks['webmail_bottom']['filters'] = 'start_filters';
 }
 
 function filters_special_mailbox( $mb ) {
@@ -86,7 +129,7 @@ function filters_special_mailbox( $mb ) {
 
 }
 
-function squirrelmail_plugin_optpage_register_block() {
+function filters_optpage_register_block() {
     global $optpage_blocks;
     global $AllowSpamFilters;
 
