@@ -21,7 +21,7 @@
  *
  * Also view plugins/README.plugins for more information.
  *
- * $Id: spamoptions.php,v 1.6 2002/02/10 15:43:47 philippe_mingo Exp $
+ * $Id: spamoptions.php,v 1.7.2.2 2002/08/21 04:36:08 jmunro Exp $
  */
 
 chdir ('..');
@@ -32,17 +32,28 @@ require_once('../src/load_prefs.php');
 
 global $AllowSpamFilters;
 
+$username = $_SESSION['username'];
+$key = $_COOKIE['key'];
+$onetimepad = $_SESSION['onetimepad'];
+$delimiter = $_SESSION['delimiter'];
+
+if (isset($_GET['action'])) {
+    $action = $_GET['action'];
+}
+
 displayPageHeader($color, 'None');
 
-if (isset($spam_submit)) {
+if (isset($_POST['spam_submit'])) {
     $spam_filters = load_spam_filters();
-    setPref($data_dir, $username, 'filters_spam_folder', $filters_spam_folder_set);
-    setPref($data_dir, $username, 'filters_spam_scan', $filters_spam_scan_set);
+    setPref($data_dir, $username, 'filters_spam_folder', $_POST['filters_spam_folder_set']);
+    setPref($data_dir, $username, 'filters_spam_scan', $_POST['filters_spam_scan_set']);
     foreach ($spam_filters as $Key => $Value) {
         $input = $spam_filters[$Key]['prefname'] . '_set';
-        if ( isset( $$input ) ) {
+        if ( isset( $_POST[$input] ) ) {
             setPref( $data_dir, $username, $spam_filters[$Key]['prefname'],
-                     $$input);
+                     $_POST[$input]);
+        } else {
+            removePref($data_dir, $username, $spam_filters[$Key]['prefname']);
         }
     }
 }
@@ -68,9 +79,9 @@ if (isset($action) && $action == 'spam') {
     sqimap_logout($imapConnection);
     for ($i = 0; $i < count($boxes) && $filters_spam_folder == ''; $i++) {
 
-        if ($boxes[$i]['flags'][0] != 'noselect' &&
-            $boxes[$i]['flags'][1] != 'noselect' &&
-            $boxes[$i]['flags'][2] != 'noselect') {
+        if ((isset($boxes[$i]['flags'][0]) && $boxes[$i]['flags'][0] != 'noselect') &&
+            (isset($boxes[$i]['flags'][1]) && $boxes[$i]['flags'][1] != 'noselect') &&
+            (isset($boxes[$i]['flags'][2]) && $boxes[$i]['flags'][2] != 'noselect')) {
             $filters_spam_folder = $boxes[$i]['unformatted'];
         }
     }
@@ -151,7 +162,7 @@ if (isset($action) && $action == 'spam') {
 
 }
 
-if (! isset($action) || $action != 'spam') {
+if (! isset($_GET['action']) || $_GET['action'] != 'spam') {
 
     echo '<p align=center>[<a href="spamoptions.php?action=spam">' . _("Edit") . '</a>]' .
          ' - [<a href="../../src/options.php">' . _("Done") . '</a>]</center><br><br>';
@@ -189,4 +200,4 @@ if (! isset($action) || $action != 'spam') {
     echo '</table>';
 }
 
-?>
\ No newline at end of file
+?>
