@@ -7,10 +7,10 @@
  * Copyright (c) 1999-2002 The SquirrelMail development team
  * Licensed under the GNU GPL. For full terms see the file COPYING.
  *
- * $Id: sqspell_functions.php,v 1.7 2002/01/31 03:45:53 graf25 Exp $
+ * $Id: sqspell_functions.php,v 1.8.2.4 2002/10/29 19:01:28 kink Exp $
  *
- * @author Konstantin Riabitsev <icon@duke.edu> ($Author: graf25 $)
- * @version $Date: 2002/01/31 03:45:53 $
+ * @author Konstantin Riabitsev <icon@duke.edu> ($Author: kink $)
+ * @version $Date: 2002/10/29 19:01:28 $
  */
 
 /**
@@ -26,7 +26,18 @@
  * @return            void
  */
 function sqspell_makePage($title, $scriptsrc, $body){
-  global $color, $SQSPELL_VERSION, $MOD;
+  global $color, $SQSPELL_VERSION;
+
+  if ( !check_php_version(4,1) ) {
+      global $_GET;
+  }
+  if (isset($_GET['MOD'])) {
+    $MOD = $_GET['MOD'];
+  }
+  else {
+    $MOD = "options_main";
+  }
+
   displayPageHeader($color, 'None');  
   echo "&nbsp;<br>\n";
   /**
@@ -326,8 +337,12 @@ function sqspell_getWords(){
      * the user's old mailbox password. I admin, this is rather dirty,
      * but efficient. ;)
      */
-    global $key, $onetimepad, $old_key;
-    if ($old_key) {
+
+    $key = $_COOKIE['key'];
+    $onetimepad = $_SESSION['onetimepad'];
+    $old_key = $_POST['old_key'];
+
+    if ($old_key != '') {
       $clear_key=$old_key;
     } else {
       /**
@@ -434,7 +449,9 @@ function sqspell_writeWords($words){
      * User wants to encrypt the file. So be it.
      * Get the user's password to use as a key.
      */
-    global $key, $onetimepad;
+    $key = $_COOKIE['key'];
+    $onetimepad = $_SESSION['onetimepad'];
+
     $clear_key=OneTimePadDecrypt($key, $onetimepad);
     /**
      * Try encrypting it. If fails, scream bloody hell.
@@ -513,5 +530,5 @@ function sqspell_ckMOD($rMOD){
  * of the user dictionary files and messing with this can do ugly 
  * stuff. :)
  */
-$SQSPELL_VERSION="v0.3.7";
+$SQSPELL_VERSION="v0.3.8";
 ?>
