@@ -12,12 +12,30 @@
  *       addrbook_search_html.html -- If you change one,
  *       change the other one too!
  *
- * $Id: addrbook_search.php,v 1.37 2002/02/20 23:29:45 jmunro Exp $
+ * $Id: addrbook_search.php,v 1.38.2.1 2002/08/03 20:48:01 ullgren Exp $
  */
 
 require_once('../src/validate.php');
 require_once('../functions/strings.php');
 
+/* lets get the global vars we may need */
+$key  = $_COOKIE['key'];
+$username = $_SESSION['username'];
+$onetimepad = $_SESSION['onetimepad'];
+$base_uri = $_SESSION['base_uri'];
+
+sqextractGlobalVar('show');
+if ( isset($_POST['query']) ) {
+    $query = $_POST['query'];
+}
+if ( isset($_POST['listall']) ) {
+    $listall = $_POST['listall'];
+}
+if ( isset($_POST['backend'] ) ) {
+    $backend = $_POST['backend'];
+}
+
+
 /* Function to include JavaScript code */
 function insert_javascript() {
     ?>
@@ -189,7 +207,7 @@ if ($show == 'form' && empty($listall)) {
     }
         
     echo '</TD></TR><TR><TD></TD><TD align=left>'.
-					'<INPUT TYPE=submit VALUE="' . _("Search") . '" NAME=show>' .
+         '<INPUT TYPE=submit VALUE="' . _("Search") . '" NAME=show>' .
          '&nbsp;|&nbsp;<INPUT TYPE=submit VALUE="' . _("List all") .
          '" NAME=listall>' . "\n" .
          '&nbsp;|&nbsp;<INPUT TYPE=button VALUE="' . _("Close") .
