@@ -10,17 +10,27 @@
  * scripts which do most of the work. Also handles the Special
  * Folders.
  *
- * $Id: folders.php,v 1.92.2.1 2002/06/11 02:25:55 jmunro Exp $
+ * $Id: folders.php,v 1.92.2.8 2002/10/28 15:41:31 kink Exp $
  */
 
 require_once('../src/validate.php');
-require_once('../functions/imap_utf7_decode_local.php');
 require_once('../functions/imap.php');
 require_once('../functions/array.php');
 require_once('../functions/plugin.php');
 
 displayPageHeader($color, 'None');
 
+/* get globals we may need */
+
+$username = $_SESSION['username'];
+$key = $_COOKIE['key'];
+$delimiter = $_SESSION['delimiter'];
+$onetimepad = $_SESSION['onetimepad'];
+if (isset($_GET['success'])) {
+    $success = $_GET['success'];
+}
+
+/* end of get globals */
 ?>
 
 <br>
@@ -34,9 +44,7 @@ displayPageHeader($color, 'None');
 
 <?php
 
-if ((isset($success) && $success) ||
-    (isset($sent_create) && $sent_create == 'true') ||
-    (isset($trash_create) && $trash_create == 'true')) {
+if ( isset($success) && $success ) {
     echo "<table width=\"100%\" align=center cellpadding=4 cellspacing=0 border=0>\n" .
          "   <tr><td align=center>\n";
     if ($success == "subscribe") {
@@ -50,9 +58,9 @@ if ((isset($success) && $success) ||
     } else if ($success == "rename") {
         echo "<b>" . _("Renamed successfully!") . "</b><br>";
     }
-
-    echo "   <a href=\"../src/left_main.php\" target=left>" . _("refresh folder list") . "</a>".
-         "   </td></tr>\n";
+    unset($success);
+    echo "   <a href=\"../src/webmail.php?right_frame=folders.php\" target=_top>" . _("refresh folder list") . "</a>".
+         "   </td></tr>\n".
          "</table><br>\n";
 } else {
     echo "<br>";
@@ -88,8 +96,8 @@ for ($i = 0; $i < count($boxes); $i++) {
             echo "<OPTION SELECTED VALUE=\"$box\">$box2</option>\n";
         } else {
             $box = $boxes[$i]['unformatted'];
-            $box2 = imap_utf7_decode_local(
-		      str_replace(' ', '&nbsp;', $boxes[$i]['unformatted-disp']));
+            $box2 = str_replace(' ','&nbsp;',imap_utf7_decode_local(
+                $boxes[$i]['unformatted-disp']));
             if (strtolower($imap_server_type) != 'courier' ||
                   strtolower($box) != "inbox.trash")
                 echo "<OPTION VALUE=\"$box\">$box2</option>\n";
@@ -260,7 +268,6 @@ for ($i = 0, $q = 0; $i < count($boxes_all); $i++) {
         $q++;
     }
 }
-sqimap_logout($imap_stream);
 
 if ($box && $box2) {
     echo "<FORM ACTION=\"folders_subscribe.php?method=sub\" METHOD=\"POST\">\n";
