@@ -9,28 +9,42 @@
  * Creates folders on the IMAP server.
  * Called from folders.php
  *
- * $Id: folders_create.php,v 1.53 2002/02/02 17:44:20 kink Exp $
+ * $Id: folders_create.php,v 1.54.2.5 2002/10/28 15:41:31 kink Exp $
  */
 
 require_once('../src/validate.php');
 require_once('../functions/imap.php');
 require_once('../functions/display_messages.php');
 
-$imapConnection = sqimap_login($username, $key, $imapServerAddress, $imapPort, 0);
-global $delimiter;
+/* get globals we may need */
 
+$username = $_SESSION['username'];
+$key = $_COOKIE['key'];
+$delimiter = $_SESSION['delimiter'];
+$onetimepad = $_SESSION['onetimepad'];
+$folder_name = $_POST['folder_name'];
+$subfolder = $_POST['subfolder'];
+if (isset($_POST['contain_subs'])) {
+    $contain_subs = $_POST['contain_subs'];
+}
+
+/* end of get globals */
+ 
 $folder_name = trim($folder_name);
 
-if (strpos($folder_name, "\"") || strpos($folder_name, "\\") ||
-    strpos($folder_name, "'") || strpos($folder_name, "$delimiter")) {
-    echo "<html><body bgcolor=$color[4]>";
+if (substr_count($folder_name, '"') || substr_count($folder_name, "\\") ||
+    substr_count($folder_name, $delimiter) || ($folder_name == '')) {
+    displayPageHeader($color, 'None');
+
     plain_error_message(_("Illegal folder name.  Please select a different name.")."<BR><A HREF=\"../src/folders.php\">"._("Click here to go back")."</A>.", $color);
-    sqimap_logout($imapConnection);
+
     exit;
 }
 
+$folder_name = imap_utf7_encode_local($folder_name);
+
 if (isset($contain_subs) && $contain_subs ) {
-    $folder_name = "$folder_name$delimiter";
+    $folder_name = $folder_name.$delimiter;
 }
 
 if ($folder_prefix && (substr($folder_prefix, -1) != $delimiter)) {
@@ -43,13 +57,17 @@ if ($folder_prefix && (substr($subfolder, 0, strlen($folder_prefix)) != $folder_
     $subfolder_orig = $subfolder;
 }
 
+$imapConnection = sqimap_login($username, $key, $imapServerAddress, $imapPort, 0);
+
 if (trim($subfolder_orig) == '') {
     sqimap_mailbox_create ($imapConnection, $folder_prefix.$folder_name, '');
 } else {
     sqimap_mailbox_create ($imapConnection, $subfolder.$delimiter.$folder_name, '');
 }
 
+sqimap_logout($imapConnection);
+
 $location = get_location();
 header ("Location: $location/folders.php?success=create");
-sqimap_logout($imapConnection);
+
 ?>
