@@ -9,7 +9,7 @@
  * Deltes folders from the IMAP server. 
  * Called from the folders.php
  *
- * $Id: folders_delete.php,v 1.49 2002/02/04 15:09:59 simond Exp $
+ * $Id: folders_delete.php,v 1.50.2.3 2002/10/23 18:33:43 kink Exp $
  */
 
 
@@ -17,15 +17,35 @@ require_once('../src/validate.php');
 require_once('../functions/imap.php');
 require_once('../functions/array.php');
 require_once('../functions/tree.php');
+require_once('../functions/display_messages.php');
 
 /*
 *  Incoming values:
 *     $mailbox - selected mailbox from the form
 */
 
+/* globals */
+$username = $_SESSION['username'];
+$key = $_COOKIE['key'];
+$delimiter = $_SESSION['delimiter'];
+$onetimepad = $_SESSION['onetimepad'];
+
+$mailbox = $_POST['mailbox'];
+
+/* end globals */
+
+if ($mailbox == '') {
+    displayPageHeader($color, 'None');
+
+    plain_error_message(_("You have not selected a folder to delete. Please do so.").
+        "<BR><A HREF=\"../src/folders.php\">"._("Click here to go back")."</A>.", $color);
+    exit;
+}
+
+
 $imap_stream = sqimap_login($username, $key, $imapServerAddress, $imapPort, 0);
 $boxes = sqimap_mailbox_list ($imap_stream);
-global $delimiter, $delete_folder;
+global $delete_folder;
 
 if (substr($mailbox, -1) == $delimiter)
     $mailbox_no_dm = substr($mailbox, 0, strlen($mailbox) - 1);
@@ -35,24 +55,24 @@ else
 /** lets see if we CAN move folders to the trash.. otherwise,
     ** just delete them **/
 
-// Courier IMAP doesn't like subfolders of Trash
+/* Courier IMAP doesn't like subfolders of Trash */
 if (strtolower($imap_server_type) == "courier") {
     $can_move_to_trash = false;
 }
 
-// If global options say we can't move it into Trash
+/* If global options say we can't move it into Trash */
 else if(isset($delete_folder) && $delete_folder == true) {
     $can_move_to_trash = false;
 }
 
-// If it's already a subfolder of trash, we'll have to delete it
+/* If it's already a subfolder of trash, we'll have to delete it */
 else if(eregi("^".$trash_folder.".+", $mailbox)) {
 
     $can_move_to_trash = false;
 
 }
 
-// Otherwise, check if trash folder exits and support sub-folders
+/* Otherwise, check if trash folder exits and support sub-folders */
 else {
     for ($i = 0; $i < count($boxes); $i++) {
         if ($boxes[$i]["unformatted"] == $trash_folder) {
@@ -69,16 +89,15 @@ for ($i = 0;$i < count($boxes);$i++) {
         continue;
     }
 }
-// Now create the nodes for subfolders of the parent folder
-// You can tell that it is a subfolder by tacking the mailbox delimiter
-//    on the end of the $mailbox string, and compare to that.
-$j = 0;
+/* Now create the nodes for subfolders of the parent folder
+   You can tell that it is a subfolder by tacking the mailbox delimiter
+   on the end of the $mailbox string, and compare to that.  */
 for ($i = 0;$i < count($boxes);$i++) {
     if (substr($boxes[$i]["unformatted"], 0, strlen($mailbox_no_dm . $delimiter)) == ($mailbox_no_dm . $delimiter)) {
         addChildNodeToTree($boxes[$i]["unformatted"], $boxes[$i]["unformatted-dm"], $foldersTree);
     }
 }
-//   simpleWalkTreePre(0, $foldersTree);
+/*   simpleWalkTreePre(0, $foldersTree); */
 
 /** Lets start removing the folders and messages **/
 if (($move_to_trash == true) && ($can_move_to_trash == true)) { /** if they wish to move messages to the trash **/
@@ -93,17 +112,5 @@ sqimap_logout($imap_stream);
 
 $location = get_location();
 header ("Location: $location/folders.php?success=delete");
-/*
-echo "<BR><BR><BR><CENTER><B>";
-echo _("Folder Deleted!");
-echo "</B><BR><BR>";
-echo _("The folder has been successfully deleted.");
-echo "<BR><A HREF=\"webmail.php?right_frame=folders.php\" TARGET=_top>";
-echo _("Click here");
-echo "</A> ";
-echo _("to continue.");
-echo "</CENTER>";
 
-echo "</BODY></HTML>";
-*/
 ?>
