@@ -9,14 +9,31 @@
  * Does the actual renaming of files on the IMAP server.
  * Called from the folders.php
  *
- * $Id: folders_rename_do.php,v 1.40 2002/01/11 23:28:12 philippe_mingo Exp $
+ * $Id: folders_rename_do.php,v 1.41.2.2 2002/10/28 15:41:31 kink Exp $
  */
 
-global $delimiter, $base_uri;
-
 require_once('../src/validate.php');
 require_once('../functions/imap.php');
 
+/* globals */
+$username = $_SESSION['username'];
+$key = $_COOKIE['key'];
+$delimiter = $_SESSION['delimiter'];
+$onetimepad = $_SESSION['onetimepad'];
+$base_uri = $_SESSION['base_uri'];
+
+$orig = $_POST['orig'];
+$old_name = $_POST['old_name'];
+$new_name = $_POST['new_name'];
+
+/* end globals */
+
+$new_name = trim($new_name);
+
+$orig = imap_utf7_encode_local($orig);
+$old_name = imap_utf7_encode_local($old_name);
+$new_name = imap_utf7_encode_local($new_name);
+
 if ($old_name <> $new_name) {
 
     $imapConnection = sqimap_login($username, $key, $imapServerAddress, $imapPort, 0);
@@ -45,5 +62,5 @@ if ($old_name <> $new_name) {
     sqimap_logout($imapConnection);
 
 }
-header ('Location: ' . $base_uri . 'src/folders.php');
+header ('Location: ' . $base_uri . 'src/folders.php?success=rename');
 ?>
