@@ -9,15 +9,32 @@
  * Gets folder names and enables renaming
  * Called from folders.php
  *
- * $Id: folders_rename_getname.php,v 1.36 2002/01/27 09:13:16 philippe_mingo Exp $
+ * $Id: folders_rename_getname.php,v 1.37.2.4 2002/10/28 15:41:31 kink Exp $
  */
 
-global $delimiter;
-
 require_once('../src/validate.php');
 require_once('../functions/imap.php');
+require_once('../functions/display_messages.php');
+
+/* get globals we may need */
+
+$username = $_SESSION['username'];
+$key = $_COOKIE['key'];
+$delimiter = $_SESSION['delimiter'];
+$onetimepad = $_SESSION['onetimepad'];
+
+$old = $_POST['old'];
+    
+/* end of get globals */
+
+displayPageHeader($color, 'None');
+
+if ($old == '') {
+    plain_error_message(_("You have not selected a folder to rename. Please do so.").
+        "<BR><A HREF=\"../src/folders.php\">"._("Click here to go back")."</A>.", $color);
+    exit;
+}
 
-$imapConnection = sqimap_login($username, $key, $imapServerAddress, $imapPort, 0);
 
 if (substr($old, strlen($old) - strlen($delimiter)) == $delimiter) {
     $isfolder = TRUE;
@@ -26,6 +43,8 @@ if (substr($old, strlen($old) - strlen($delimiter)) == $delimiter) {
     $isfolder = FALSE;
 }
 
+$old = imap_utf7_decode_local($old);
+
 if (strpos($old, $delimiter)) {
     $old_name = substr($old, strrpos($old, $delimiter)+1, strlen($old));
     $old_parent = substr($old, 0, strrpos($old, $delimiter));
@@ -34,7 +53,6 @@ if (strpos($old, $delimiter)) {
     $old_parent = '';
 }
 
-displayPageHeader($color, 'None');
 echo "<br><TABLE align=center border=0 WIDTH=\"95%\" COLS=1>".
      "<TR><TD BGCOLOR=\"$color[0]\" ALIGN=CENTER><B>".
      _("Rename a folder").
@@ -52,6 +70,4 @@ echo "<INPUT TYPE=SUBMIT VALUE=\""._("Submit")."\">\n".
      "</FORM><BR></TD></TR>".
      "</TABLE>";
 
-/** Log out this session **/
-sqimap_logout($imapConnection);
-?>
\ No newline at end of file
+?>
