@@ -9,7 +9,7 @@
  * Loads preferences from the $username.pref file used by almost
  * every other script in the source directory and alswhere.
  *
- * $Id: load_prefs.php,v 1.91 2002/02/14 21:57:18 ullgren Exp $
+ * $Id: load_prefs.php,v 1.99.2.3 2002/10/29 21:34:36 kink Exp $
  */
 
 require_once('../src/validate.php');
@@ -17,6 +17,10 @@ require_once('../functions/prefs.php');
 require_once('../functions/plugin.php');
 require_once('../functions/constants.php');
 
+/* get globals we may need */
+$username = $_SESSION['username'];
+/* end of get globals */
+
 $username = ( !isset($username) ? '' : $username );
 
 $custom_css = getPref($data_dir, $username, 'custom_css', 'none' );
@@ -63,7 +67,7 @@ if (isset($chosen_theme) && $found_theme && (file_exists($chosen_theme))) {
 }
 
 if (!defined('download_php')) { 
-    session_register('theme_css'); 
+    sqsession_register($theme_css, 'theme_css'); 
 }
 
 $use_javascript_addr_book = getPref($data_dir, $username, 'use_javascript_addr_book', $default_use_javascript_addr_book);
@@ -142,19 +146,30 @@ $reply_citation_style =
 $reply_citation_start = getPref($data_dir, $username, 'reply_citation_start');
 $reply_citation_end = getPref($data_dir, $username, 'reply_citation_end');
 
+/* left refresh rate, strtolower makes 1.0.6 prefs compatible */
 $left_refresh = getPref($data_dir, $username, 'left_refresh', SMPREF_NONE );
+$left_refresh = strtolower($left_refresh);
+
 $sort = getPref($data_dir, $username, 'sort', 6 );
 
 /** Load up the Signature file **/
 $signature_abs = $signature = getSig($data_dir, $username, "g");
 
-/* Highlight comes in with the form: name, color, header, value. */
-for ($i = 0; $hlt = getPref($data_dir, $username, "highlight$i"); ++$i) {
-    $highlight_array = explode(',', $hlt);
-    $message_highlight_list[$i]['name'] = $highlight_array[0];
-    $message_highlight_list[$i]['color'] = $highlight_array[1];
-    $message_highlight_list[$i]['value'] = $highlight_array[2];
-    $message_highlight_list[$i]['match_type'] = $highlight_array[3];
+/* use new way of storing highlighting rules */
+if( $ser = getPref($data_dir, $username, 'hililist') ) {
+    $message_highlight_list = unserialize($ser);
+} else {
+    /* use old way */
+    for ($i = 0; $hlt = getPref($data_dir, $username, "highlight$i"); ++$i) {
+        $highlight_array = explode(',', $hlt);
+        $message_highlight_list[$i]['name'] = $highlight_array[0];
+        $message_highlight_list[$i]['color'] = $highlight_array[1];
+        $message_highlight_list[$i]['value'] = $highlight_array[2];
+        $message_highlight_list[$i]['match_type'] = $highlight_array[3];
+        removePref($data_dir, $user_name, "highlight$i");
+    }
+    /* store in new format for the next time */
+    setPref($data_dir, $username, 'hililist', serialize($message_highlight_list));
 }
 
 /* Index order lets you change the order of the message index */
@@ -192,6 +207,7 @@ $attachment_common_show_images = getPref($data_dir, $username, 'attachment_commo
 $pf_subtle_link = getPref($data_dir, $username, 'pf_subtle_link', SMPREF_ON);
 $pf_cleandisplay = getPref($data_dir, $username, 'pf_cleandisplay', SMPREF_OFF);
 
+/* message disposition notification support setting */
 $mdn_user_support = getPref($data_dir, $username, 'mdn_user_support', SMPREF_ON);
 
 $include_self_reply_all =
@@ -206,6 +222,18 @@ $hour_format = getPref($data_dir, $username, 'hour_format', 2);
 
 /*  compose in new window setting */
 $compose_new_win = getPref($data_dir, $username, 'compose_new_win', 0);
+$compose_height = getPref($data_dir, $username, 'compose_height', 550);
+$compose_width = getPref($data_dir, $username, 'compose_width', 640);
+
+
+/* signature placement settings */
+$sig_first = getPref($data_dir, $username, 'sig_first', 0);
+
+/* use the internal date of the message for sorting instead of the supplied header date */
+$internal_date_sort = getPref($data_dir, $username, 'internal_date_sort', SMPREF_ON);
+
+/* if server sorting is enabled/disabled */
+$sort_by_ref = getPref($data_dir, $username, 'sort_by_ref', 1);
 
 /* Load the javascript settings. */
 $javascript_setting =
@@ -215,6 +243,8 @@ $javascript_on = getPref($data_dir, $username, 'javascript_on', SMPREF_ON);
 
 $search_memory = getPref($data_dir, $username, 'search_memory', 0);
 
+$forward_cc = getPref($data_dir, $username, 'forward_cc', 0);
+
 do_hook('loading_prefs');
 
 ?>
