@@ -8,7 +8,7 @@
  *
  * Displays all optinos about display preferences
  *
- * $Id: options_display.php,v 1.68 2002/02/11 18:25:59 jmunro Exp $
+ * $Id: options_display.php,v 1.76.2.5 2002/10/29 19:01:29 kink Exp $
  */
 
 /* Define the group constants for the display options page. */
@@ -18,7 +18,8 @@ define('SMOPT_GRP_MESSAGE', 2);
 
 /* Define the optpage load function for the display options page. */
 function load_optpage_data_display() {
-    global $theme, $language, $languages, $js_autodetect_results, $default_use_mdn;
+    global $theme, $language, $languages, $js_autodetect_results,
+    $compose_new_win, $default_use_mdn, $squirrelmail_language, $allow_thread_sort;
 
     /* Build a simple array into which we will build options. */
     $optgrps = array();
@@ -78,6 +79,7 @@ function load_optpage_data_display() {
     asort($language_values);
     $language_values =
         array_merge(array('' => _("Default")), $language_values);
+    $language = $squirrelmail_language;
     $optvals[SMOPT_GRP_GENERAL][] = array(
         'name'    => 'language',
         'caption' => _("Language"),
@@ -175,6 +177,7 @@ function load_optpage_data_display() {
                            SMPREF_LOC_BOTTOM  => _("After message body"))
     );
 
+
     $optvals[SMOPT_GRP_MESSAGE][] = array(
         'name'    => 'use_javascript_addr_book',
         'caption' => _("Addressbook Display Format"),
@@ -198,6 +201,13 @@ function load_optpage_data_display() {
         'refresh' => SMOPT_REFRESH_NONE
     );
 
+    $optvals[SMOPT_GRP_MESSAGE][] = array(
+        'name'    => 'forward_cc',
+        'caption' => _("Include CCs when forwarding messages"),
+        'type'    => SMOPT_TYPE_BOOLEAN,
+        'refresh' => SMOPT_REFRESH_NONE
+    );
+
     $optvals[SMOPT_GRP_MESSAGE][] = array(
         'name'    => 'show_xmailer_default',
         'caption' => _("Enable Mailer Display"),
@@ -225,6 +235,7 @@ function load_optpage_data_display() {
         'type'    => SMOPT_TYPE_BOOLEAN,
         'refresh' => SMOPT_REFRESH_NONE
     );
+
     if ($default_use_mdn) {
         $optvals[SMOPT_GRP_MESSAGE][] = array(
             'name'    => 'mdn_user_support',
@@ -233,12 +244,51 @@ function load_optpage_data_display() {
             'refresh' => SMOPT_REFRESH_NONE
         );
     }
+
     $optvals[SMOPT_GRP_MESSAGE][] = array(
         'name'    => 'compose_new_win',
         'caption' => _("Always compose in a new window"),
         'type'    => SMOPT_TYPE_BOOLEAN,
         'refresh' => SMOPT_REFRESH_ALL
     );
+
+    $optvals[SMOPT_GRP_MESSAGE][] = array(
+        'name'    => 'compose_width',
+        'caption' => _("Width of compose window"),
+        'type'    => SMOPT_TYPE_INTEGER,
+        'refresh' => SMOPT_REFRESH_ALL,
+        'size'    => SMOPT_SIZE_TINY
+    );
+
+    $optvals[SMOPT_GRP_MESSAGE][] = array(
+        'name'    => 'compose_height',
+        'caption' => _("Height of compose window"),
+        'type'    => SMOPT_TYPE_INTEGER,
+        'refresh' => SMOPT_REFRESH_ALL,
+        'size'    => SMOPT_SIZE_TINY
+    );
+
+    $optvals[SMOPT_GRP_MESSAGE][] = array(
+        'name'    => 'sig_first',
+        'caption' => _("Append signature before reply/forward text"),
+        'type'    => SMOPT_TYPE_BOOLEAN,
+        'refresh' => SMOPT_REFRESH_NONE
+    );
+
+    $optvals[SMOPT_GRP_MESSAGE][] = array(
+        'name'    => 'internal_date_sort',
+        'caption' => _("Use receive date for sort"),
+        'type'    => SMOPT_TYPE_BOOLEAN,
+        'refresh' => SMOPT_REFRESH_ALL
+    );
+    if ($allow_thread_sort == TRUE) {
+        $optvals[SMOPT_GRP_MESSAGE][] = array(
+            'name'    => 'sort_by_ref',
+            'caption' => _("Use References header for thread sort"),
+            'type'    => SMOPT_TYPE_BOOLEAN,
+            'refresh' => SMOPT_REFRESH_ALL
+        );
+    }
     /* Assemble all this together and return it as our result. */
     $result = array(
         'grps' => $optgrps,
@@ -272,7 +322,11 @@ function save_option_theme($option) {
 }
 
 function save_option_javascript_autodetect($option) {
-    global $data_dir, $username, $new_javascript_setting;
+    global $data_dir, $new_javascript_setting;
+    if ( !check_php_version(4,1) ) {
+        global $_SESSION;
+    }
+        $username = $_SESSION['username'];
 
     /* Set javascript either on or off. */
     if ($new_javascript_setting == SMPREF_JS_AUTODETECT) {
