@@ -8,7 +8,7 @@
  *
  * Displays message highlighting options
  *
- * $Id: options_highlight.php,v 1.35 2002/02/19 12:31:12 brong Exp $
+ * $Id: options_highlight.php,v 1.37.2.3 2002/10/29 22:05:39 kink Exp $
  */
 
 require_once('../src/validate.php');
@@ -18,6 +18,33 @@ require_once('../functions/array.php');
 require_once('../functions/plugin.php');
 require_once('../functions/strings.php');
 
+/* get globals */
+if (isset($_GET['action'])) {
+    $action = $_GET['action'];
+}
+if (isset($_GET['theid'])) {
+    $theid = $_GET['theid'];
+}
+if (isset($_GET['identname'])) {
+    $identname = $_GET['identname'];
+}
+if (isset($_GET['newcolor_choose'])) {
+    $newcolor_choose = $_GET['newcolor_choose'];
+}
+if (isset($_GET['newcolor_input'])) {
+    $newcolor_input = $_GET['newcolor_input'];
+}
+if (isset($_GET['color_type'])) {
+    $color_type = $_GET['color_type'];
+}
+if (isset($_GET['match_type'])) {
+    $match_type = $_GET['match_type'];
+}
+if (isset($_GET['value'])) {
+    $value = $_GET['value'];
+}
+/* end of get globals */
+
 function oh_opt( $val, $sel, $tit ) {
     echo "<option value=\"$val\"";
     if ( $sel )
@@ -33,27 +60,40 @@ if (! isset($message_highlight_list)) {
 }
 
 if ($action == 'delete' && isset($theid)) {
-    removePref($data_dir, $username, "highlight$theid");
-    header( "Location: $PHP_SELF" );
+
+    $new_rules = array();
+    foreach($message_highlight_list as $rid => $rule) {
+         if($rid != $theid) {
+             $new_rules[] = $rule;
+         }
+    }
+    $message_highlight_list = $new_rules;    
+
+    setPref($data_dir, $username, 'hililist', serialize($message_highlight_list));
+
+    header( 'Location: options_highlight.php' );
     exit;
 } else if ($action == 'save') {
-    if (!$theid) $theid = 0;
-    $identname = str_replace(',', ' ', $identname);
     if ($color_type == 1) $newcolor = $newcolor_choose;
     elseif ($color_type == 2) $newcolor = $newcolor_input;
     else $newcolor = $color_type;
 
-    $newcolor = str_replace(',', '', $newcolor);
     $newcolor = str_replace('#', '', $newcolor);
     $newcolor = str_replace('"', '', $newcolor);
     $newcolor = str_replace('\'', '', $newcolor);
     $value = str_replace(',', ' ', $value);
 
-    setPref($data_dir, $username, "highlight$theid", $identname.','.$newcolor.','.$value.','.$match_type);
-    $message_highlight_list[$theid]['name'] = $identname;
-    $message_highlight_list[$theid]['color'] = $newcolor;
-    $message_highlight_list[$theid]['value'] = $value;
-    $message_highlight_list[$theid]['match_type'] = $match_type;
+    if(isset($theid)) {
+        $message_highlight_list[$theid] = 
+            array( 'name' => $identname, 'color' => $newcolor,
+                   'value' => $value, 'match_type' => $match_type );
+    } else {
+        $message_highlight_list[] = 
+            array( 'name' => $identname, 'color' => $newcolor,
+                   'value' => $value, 'match_type' => $match_type );
+    }
+
+    setPref($data_dir, $username, 'hililist', serialize($message_highlight_list));
 }
 displayPageHeader($color, 'None');
 ?>
@@ -88,11 +128,6 @@ if (count($message_highlight_list) >= 1) {
         "<br>\n";
 }
 if ($action == 'edit' || $action == 'add') {
-    if (!isset($theid))
-    {
-        $theid = count($message_highlight_list);
-        $message_highlight_list[$theid] = array();
-    }
 
     $color_list[0] = '4444aa';
     $color_list[1] = '44aa44';
@@ -236,7 +271,7 @@ if ($action == 'edit' || $action == 'add') {
     for ($i=0; $i < 14; $i++) {
         ${"selected".$i} = '';
     }
-    if (isset($message_highlight_list[$theid]['color'])) {
+    if ($action == 'edit' && isset($message_highlight_list[$theid]['color'])) {
         for ($i=0; $i < 14; $i++) {
             if ($color_list[$i] == $message_highlight_list[$theid]['color']) {
             $selected_choose = ' checked';
@@ -252,14 +287,15 @@ if ($action == 'edit' || $action == 'add') {
 
     echo '<form name="f" action="options_highlight.php">' . "\n";
     echo '<input type="hidden" value="save" name="action">' . "\n";
-    echo '<input type="hidden" value="'.$theid.'" name="theid">' . "\n";
+    if($action == 'edit')
+        echo '<input type="hidden" value="'.$theid.'" name="theid">' ."\n";
     echo '<table width="80%" align="center" cellpadding="3" cellspacing="0" border="0">' . "\n";
     echo "   <tr bgcolor=\"$color[0]\">\n";
     echo "      <td align=\"right\" nowrap><b>\n";
     echo _("Identifying name") . ":";
     echo '      </b></td>' . "\n";
     echo '      <td>' . "\n";
-    if (isset($message_highlight_list[$theid]['name']))
+    if ($action == 'edit' && isset($message_highlight_list[$theid]['name']))
         $disp = $message_highlight_list[$theid]['name'];
     else
         $disp = '';
@@ -298,7 +334,12 @@ if ($action == 'edit' || $action == 'add') {
     # Show grid of color choices
     echo "<tr bgcolor=\"$color[0]\"><td colspan='2'>\n";
     echo "<table border=0 cellpadding=\"2\" align=\"center\" cellspacing=\"1\">\n";
-    $current_color = $message_highlight_list[$theid]['color'];
+    if ($action == 'edit' && isset($message_highlight_list[$theid]['color'])) {
+        $current_color = $message_highlight_list[$theid]['color'];
+    }
+    else {
+        $current_color = '63aa7f';
+    }
     for($x = 0; $x < 5; $x++) {
         echo "<tr>\n";
         for($y = 0; $y < 19; $y++) {
@@ -334,7 +375,7 @@ if ($action == 'edit' || $action == 'add') {
             _("Subject") );
     echo "         </select>\n";
     echo '<b>' . _("Matches") . ':</b> ';
-    if (isset($message_highlight_list[$theid]['value']))
+    if ($action == 'edit' && isset($message_highlight_list[$theid]['value']))
         $disp = $message_highlight_list[$theid]['value'];
     else
         $disp = '';
