@@ -6,7 +6,7 @@
  * Copyright (c) 1999-2002 The SquirrelMail Project Team
  * Licensed under the GNU GPL. For full terms see the file COPYING.
  *
- * $Id: printer_friendly_main.php,v 1.7 2002/02/19 12:31:12 brong Exp $
+ * $Id: printer_friendly_main.php,v 1.8.2.1 2002/08/01 11:55:34 kink Exp $
  */
 
 require_once('../src/validate.php');
@@ -14,8 +14,14 @@ require_once('../functions/page_header.php');
 
 displayHtmlHeader( _("Printer Friendly"), '', FALSE );
 
+/* get those globals into gear */
+$passed_ent_id = $_GET['passed_ent_id'];
+$passed_id = $_GET['passed_id'];
+$mailbox = $_GET['mailbox'];
+/* end globals */
+
 echo "<frameset rows=\"60, *\" noresize border=\"0\">\n".
-     "<frame src=\"printer_friendly_top.php\" name=\"top_frame\" scrolling=\"off\">".
+     "<frame src=\"printer_friendly_top.php\" name=\"top_frame\" scrolling=\"no\">".
      '<frame src="printer_friendly_bottom.php?passed_ent_id='.
      $passed_ent_id . '&amp;mailbox=' . urlencode($mailbox) .
      '&amp;passed_id=' . $passed_id .
