@@ -9,7 +9,7 @@
  * This file is used for reading the msgs array and displaying
  * the resulting emails in the right frame.
  *
- * $Id: read_body.php,v 1.179.2.3 2002/06/10 18:16:32 jmunro Exp $
+ * $Id: read_body.php,v 1.179.2.17 2002/10/16 15:41:44 indiri69 Exp $
  */
 
 require_once('../src/validate.php');
@@ -30,6 +30,7 @@ function findNextMessage() {
     global $msort, $currentArrayIndex, $msgs, $sort, 
            $thread_sort_messages, $allow_server_sort,
            $server_sort_array;
+
     if (!is_array($server_sort_array)) {
         $thread_sort_messages = 0;
         $allow_server_sort = FALSE;
@@ -196,9 +197,10 @@ function ServerMDNSupport( $read ) {
 }
 
 function SendMDN ( $recipient , $sender) {
-    global $imapConnection, $mailbox, $username, $attachment_dir, $SERVER_NAME,
+    global $imapConnection, $mailbox, $username, $attachment_dir, $_SERVER,
            $version, $attachments, $identity, $data_dir, $passed_id;
 
+    $SERVER_NAME = $_SERVER['SERVER_NAME'];
     $header = sqimap_get_message_header($imapConnection, $passed_id, $mailbox);
     $hashed_attachment_dir = getHashedDir($username, $attachment_dir);
 
@@ -241,7 +243,7 @@ function SendMDN ( $recipient , $sender) {
     $localfilename = GenerateRandomString(32, 'FILE', 7);
     $full_localfilename = "$hashed_attachment_dir/$localfilename";
 
-    $fp = fopen( $full_localfilename, 'w');
+    $fp = fopen( $full_localfilename, 'wb');
     fwrite ($fp, $part2);
     fclose($fp);
 
@@ -382,11 +384,80 @@ function formatRecipientString($recipients, $item ) {
  *   Main of read_boby.php  --------------------------------------------------
  */
 
-/*
-    Urled vars
-    ----------
-    $passed_id
-*/
+/* get the globals we may need */
+
+$username = $_SESSION['username'];
+$key = $_COOKIE['key'];
+$onetimepad = $_SESSION['onetimepad'];
+$msgs = $_SESSION['msgs'];
+$base_uri = $_SESSION['base_uri'];
+$delimiter = $_SESSION['delimiter'];
+
+if (isset($_GET['passed_id'])) {
+    $passed_id = $_GET['passed_id'];
+}
+elseif (isset($_POST['passed_id'])) {
+    $passed_id = $_POST['passed_id'];
+}
+
+if (isset($_GET['sendreceipt'])) {
+    $sendreceipt = $_GET['sendreceipt'];
+}
+
+if (isset($_GET['sort'])) {
+    $sort = $_GET['sort'];
+}
+elseif (isset($_POST['sort'])) {
+    $sort = $_POST['sort'];
+}
+if (isset($_GET['startMessage'])) {
+    $startMessage = $_GET['startMessage'];
+}
+elseif (isset($_POST['startMessage'])) {
+    $startMessage = $_POST['startMessage'];
+}
+if (isset($_GET['show_more'])) {
+    $show_more = $_GET['show_more'];
+}
+if (isset($_GET['show_more_cc'])) {
+    $show_more_cc = $_GET['show_more_cc'];
+}
+if (isset($_GET['show_more_bcc'])) {
+    $show_more_bcc = $_GET['show_more_bcc'];
+}
+if (isset($_GET['mailbox'])) {
+    $mailbox = $_GET['mailbox'];
+}
+elseif (isset($_POST['mailbox'])) {
+    $mailbox = $_POST['mailbox'];
+}
+if (isset($_GET['where'])) {
+    $where = $_GET['where'];
+}
+if (isset($_GET['what'])) {
+    $what = $_GET['what'];
+}
+if (isset($_GET['view_hdr'])) {
+    $view_hdr = $_GET['view_hdr'];
+}
+if (isset($_SESSION['server_sort_array'])) {
+    $server_sort_array = $_SESSION['server_sort_array'];
+}
+if (isset($_SESSION['msgs'])) {
+    $msgs = $_SESSION['msgs'];
+}
+if (isset($_SESSION['msort'])) {
+    $msort = $_SESSION['msort'];
+}
+if (isset($_POST['move_id'])) {
+    $move_id = $_POST['move_id'];
+}
+if (isset($_SESSION['lastTargetMailbox'])) {
+    $lastTargetMailbox = $_SESSION['lastTargetMailbox'];
+}
+$thread_sort_messages = getPref($data_dir, $username, "thread_$mailbox", 0);
+
+/* end of get globals */
 
 if (isset($mailbox)){
     $mailbox = urldecode( $mailbox );
@@ -672,7 +743,7 @@ echo '<BR>' .
      '<A HREF="' . $base_uri . 'src/';
 
 if ($where && $what) {
-    if ($pos == '') {
+    if (!isset($pos) || $pos == '') {
         $pos=0;
     }
     echo "search.php?where=".urlencode($where)."&amp;pos=$pos&amp;what=".urlencode($what)."&amp;mailbox=$urlMailbox\">";
@@ -688,35 +759,34 @@ if ($where && $what) {
     echo "sort=$sort&amp;startMessage=$startMessage\">";
 }
 echo _("Delete") . '</A>&nbsp;';
+$comp_uri  = $base_uri . "src/compose.php?identity=$identity&amp;" .
+             "ent_num=$ent_num&amp;mailbox=$urlMailbox&amp;";
+$comp_uri .= $default_use_priority?"mailprio=$priority_level&amp;":"";
+if ($compose_new_win == '1') {
+    $link_open  = '<a href="javascript:void(0)" onclick="comp_in_new(false,\'';
+    $link_close = '\')">';
+} else {
+    $link_open  = '<a href="';
+    $link_close = '">';
+}
+$link_open .= $comp_uri;
 if (($mailbox == $draft_folder) && ($save_as_draft)) {
-    $comp_uri = $base_uri . "src/compose.php?mailbox=$mailbox&amp;".
-                "identity=$identity&amp;send_to=$url_to_string&amp;".
-		"send_to_cc=$url_cc_string&amp;send_to_bcc=$url_bcc_string&amp;".
-		"subject=$url_subj&amp;mailprio=$priority_level&amp;".
-		"draft_id=$passed_id&amp;ent_num=$ent_num";
-    
-    if ($compose_new_win == '1') {
-        echo "<a href=\"javascript:void(0)\" onclick=\"comp_in_new(false,'$comp_uri')\"";
-    } else {
-        echo '|&nbsp;<A HREF="' . $comp_uri .'"';
-    }
-    echo '>'.
+    $draft_uri = "send_to=$url_to_string&amp;".
+                 "send_to_cc=$url_cc_string&amp;send_to_bcc=$url_bcc_string&amp;".
+                 "subject=$url_subj&amp;".
+                 "draft_id=$passed_id";
+
+    echo '|&nbsp;' . $link_open . $draft_uri . $link_close .
          _("Resume Draft") . '</a>';
 }
 if ($mailbox == $sent_folder) {
-    $comp_uri = $base_uri . "src/compose.php?mailbox=$mailbox&amp;".
-                "identity=$identity&amp;send_to=$url_to_string&amp;".
-		"send_to_cc=$url_cc_string&amp;send_to_bcc=$url_bcc_string&amp;".
-		"subject=$url_subj&amp;mailprio=$priority_level&amp;".
-		"ent_num=$ent_num&amp;passed_id=$passed_id&amp;edit_as_new=1";
+    $sent_uri = "send_to=$url_to_string&amp;".
+                "send_to_cc=$url_cc_string&amp;send_to_bcc=$url_bcc_string&amp;".
+                "subject=$url_subj&amp;".
+                "passed_id=$passed_id&amp;edit_as_new=1";
 
-    if ($compose_new_win == '1') {
-        echo "<a href=\"javascript:void(0)\" onclick=\"comp_in_new(false,'$comp_uri')\"";
-    } else {
-        echo '|&nbsp;<A HREF="' . $comp_uri .'"';
-    }
-    echo '>'.
-          _("Edit Message as New") . '</a>';
+    echo '|&nbsp;' . $link_open . $sent_uri . $link_close .
+         _("Edit Message as New") . '</a>';
 }
 
 echo '&nbsp;&nbsp;' .
@@ -750,50 +820,51 @@ echo                '</SMALL>' .
                 '</TD><TD WIDTH="33%" ALIGN="RIGHT">' .
                    '<SMALL>' ;
 
-$comp_uri = $base_uri . "src/compose.php?forward_id=$passed_id&amp;".
-            "forward_subj=$url_subj&amp;".
-	    ($default_use_priority?"mailprio=$priority_level&amp;":'').
-            "mailbox=$urlMailbox&amp;ent_num=$ent_num";
-	     		   
-if ($compose_new_win == '1') {
-    echo "<a href=\"javascript:void(0)\" onclick=\"comp_in_new(false,'$comp_uri')\"";
-} else {
-    echo '|&nbsp;<A HREF="' . $comp_uri .'"';
+
+/*
+ * Auto-Select identity for replies (Jonathan Angliss - 2002/09/25)
+ */
+ 
+$to_arr = formatRecipientString($message->header->to, 'to');
+$to_str = str_replace( array( '&gt;' , '&lt;' , '<' , '>' ) , '' , $to_arr['str']);
+$identity = '';
+$idents = getPref($data_dir, $username, 'identities');
+if (!empty($idents) && $idents > 1) {
+    for ($i = 1; $i < $idents; $i++) {
+		$ident_addr = getPref($data_dir , $username , 'email_address' . $i);
+		if ($to_str == $ident_addr) {
+            $identity = $i;
+            break;
+        }
+    }
 }
 
-    echo '>'.
-    _("Forward") .
-    '</A>&nbsp;|&nbsp;';
-
-$comp_uri = $base_uri . "src/compose.php?send_to=$url_replyto&amp;".
-            "reply_subj=$url_subj&amp;".
-            ($default_use_priority?"mailprio=$priority_level&amp;":'').
-            "reply_id=$passed_id&amp;mailbox=$urlMailbox&amp;ent_num=$ent_num";
-	        
-if ($compose_new_win == '1') {
-    echo "<a href=\"javascript:void(0)\" onclick=\"comp_in_new(false,'$comp_uri')\"";
-} else {
-    echo '|&nbsp;<A HREF="' . $comp_uri .'"';
-}
-
-    echo '>'.
-    _("Reply") .
-    '</A>&nbsp;|&nbsp;';
-
-$comp_uri = $base_uri . "src/compose.php?send_to=$url_replytoall&amp;".
-            "send_to_cc=$url_replytoallcc&amp;reply_subj=$url_subj&amp;".
-            ($default_use_priority?"mailprio=$priority_level&amp;":'').
-            "reply_id=$passed_id&amp;mailbox=$urlMailbox&amp;ent_num=$ent_num";
+$comp_uri  = $base_uri . "src/compose.php?identity=$identity&amp;" .
+             "ent_num=$ent_num&amp;mailbox=$urlMailbox&amp;";
+$comp_uri .= $default_use_priority?"mailprio=$priority_level&amp;":"";
 
 if ($compose_new_win == '1') {
-    echo "<a href=\"javascript:void(0)\" onclick=\"comp_in_new(false,'$comp_uri')\"";
+    $link_open  = '<a href="javascript:void(0)" onclick="comp_in_new(false,\'';
+    $link_close = '\')">';
 } else {
-    echo '|&nbsp;<A HREF="' . $comp_uri .'"';
+    $link_open  = '<a href="';
+    $link_close = '">';
 }
-
-    echo '>'.
-    _("Reply All") .
-    '</A>&nbsp;&nbsp;' .
+$link_open .= $comp_uri;
+$forward_uri   = "forward_id=$passed_id&amp;" .
+                 "forward_subj=$url_subj";
+$reply_uri     = "send_to=$url_replyto&amp;".
+                 "reply_subj=$url_subj&amp;".
+                 "reply_id=$passed_id";
+$reply_all_uri = "send_to=$url_replytoall&amp;".
+                 "send_to_cc=$url_replytoallcc&amp;reply_subj=$url_subj&amp;".
+                 "reply_id=$passed_id";
+echo $link_open . $forward_uri . $link_close .
+     _("Forward") . '</a>&nbsp;|&nbsp;' .
+     $link_open . $reply_uri . $link_close .
+     _("Reply") . '</a>&nbsp;|&nbsp;' .
+     $link_open . $reply_all_uri . $link_close .
+     _("Reply All") . '</a>&nbsp;&nbsp;' .
                    '</SMALL>' .
                 '</TD>' .
              '</TR>' .
