@@ -9,7 +9,7 @@
 *
 * Prevents users from reposting their form data after a successful logout.
 *
-* $Id: redirect.php,v 1.45 2002/02/16 00:03:50 teepe Exp $
+* $Id: redirect.php,v 1.50.2.10 2002/10/08 17:15:56 jmunro Exp $
 */
 
 require_once('../functions/i18n.php');
@@ -20,24 +20,25 @@ require_once('../functions/imap.php');
 require_once('../functions/plugin.php');
 require_once('../functions/constants.php');
 require_once('../functions/page_header.php');
+require_once('../src/global.php');
 
 // Remove slashes if PHP added them
-if (get_magic_quotes_gpc()) {
-    global $REQUEST_METHOD;
 
-    if ($REQUEST_METHOD == "POST") {
-        global $HTTP_POST_VARS;
-        RemoveSlashes($HTTP_POST_VARS);
-    } else if ($REQUEST_METHOD == "GET") {
-        global $HTTP_GET_VARS;
-        RemoveSlashes($HTTP_GET_VARS);
+$REQUEST_METHOD = $_SERVER['REQUEST_METHOD'];
+if (get_magic_quotes_gpc()) {
+    if ($REQUEST_METHOD == 'POST') {
+        RemoveSlashes($_POST);
+    } else if ($REQUEST_METHOD == 'GET') {
+        RemoveSlashes($_GET);
     }
 }
 
 /* Before starting the session, the base URI must be known. Assuming */
 /* that this file is in the src/ subdirectory (or something).        */
-ereg ("(^.*/)[^/]+/[^/]+$", $PHP_SELF, $regs);
-$base_uri = $regs[1];
+if (!function_exists('sqm_baseuri')){
+    require_once('../functions/display_messages.php');
+}
+$base_uri = sqm_baseuri();
 
 header('Pragma: no-cache');
 $location = get_location();
@@ -45,60 +46,73 @@ $location = get_location();
 session_set_cookie_params (0, $base_uri);
 session_start();
 
-session_unregister ('user_is_logged_in');
-session_register ('base_uri');
+sqsession_unregister ('user_is_logged_in');
+sqsession_register ($base_uri, 'base_uri');
 
-if (! isset($squirrelmail_language) ||
+
+/* get globals we me need */
+
+if (isset($_POST['login_username'])) {
+    $login_username = $_POST['login_username'];
+}
+if (!isset($_COOKIE['squirrelmail_language']) ||
     $squirrelmail_language == '' ) {
     $squirrelmail_language = $squirrelmail_default_language;
 }
+else {
+    $squirrelmail_language = $_COOKIE['squirrelmail_language'];
+}
+if (isset($_POST['secretkey'])) {
+    $secretkey = $_POST['secretkey'];
+}
+if (isset($_POST['js_autodetect_results'])) {
+    $js_autodetect_results = $_POST['js_autodetect_results'];
+}
+/* end of get globals */
+
 set_up_language($squirrelmail_language, true);
 /* Refresh the language cookie. */
-setcookie('squirrelmail_language', $squirrelmail_language, time()+2592000,$base_uri);
+setcookie('squirrelmail_language', $squirrelmail_language, time()+2592000, 
+          $base_uri);
 
 if (!isset($login_username)) {
-    displayHtmlHeader( _("You must be logged in to access this page.") );
-    echo "<BODY BGCOLOR=\"#ffffff\">\n" .
-        "<BR>&nbsp;<BR>\n" .
-        "<CENTER>\n" .
-        '<B>' . _("You must be logged in to access this page.") . "</B><BR>" .
-        '<A HREF="../src/login.php">'  . _("Go to the login page") . "</A>\n" .
-        "</CENTER>\n" .
-        "</BODY></HTML>\n";
+    include_once( '../functions/display_messages.php' );
+    logout_error( _("You must be logged in to access this page.") );    
     exit;
 }
 
-if (!session_is_registered('user_is_logged_in')) {
+if (!sqsession_is_registered('user_is_logged_in')) {
     do_hook ('login_before');
 
     $onetimepad = OneTimePadCreate(strlen($secretkey));
     $key = OneTimePadEncrypt($secretkey, $onetimepad);
-    session_register('onetimepad');
+    sqsession_register($onetimepad, 'onetimepad');
+
+    /* remove redundant spaces */
+    $login_username = trim($login_username);
 
-    /* Verify that username and password are correct. */
     if ($force_username_lowercase) {
         $login_username = strtolower($login_username);
     }
 
+    /* Verify that username and password are correct. */
+
     $imapConnection = sqimap_login($login_username, $key, $imapServerAddress, $imapPort, 0);
     if (!$imapConnection) {
-        displayHtmlHeader( _("There was an error contacting the mail server.") );
-        echo "<body bgcolor=\"#ffffff\">\n".
-            "<br> <br>\n".
-            "<center>\n".
-            '<b>' . _("There was an error contacting the mail server.") . "</b><br>\n".
-            _("Contact your administrator for help.") . "\n".
-            "</center>\n".
-            "</body></html>\n";
+        $errTitle = _("There was an error contacting the mail server.");
+        $errString = $errTitle . "<br>\n".
+                     _("Contact your administrator for help.");
+        include_once( '../functions/display_messages.php' );
+        logout_error( $errString, $errTitle );            
         exit;
     } else {
         $delimiter = sqimap_get_delimiter ($imapConnection);
     }
     sqimap_logout($imapConnection);
-    session_register('delimiter');
+    sqsession_register($delimiter, 'delimiter');
 
     $username = $login_username;
-    session_register ('username');
+    sqsession_register ($username, 'username');
     setcookie('key', $key, 0, $base_uri);
     do_hook ('login_verified');
 
@@ -109,23 +123,25 @@ $user_is_logged_in = true;
 $just_logged_in = true;
 
 /* And register with them with the session. */
-session_register ('user_is_logged_in');
-session_register ('just_logged_in');
+sqsession_register ($user_is_logged_in, 'user_is_logged_in');
+sqsession_register ($just_logged_in, 'just_logged_in');
 
 /* parse the accepted content-types of the client */
 $attachment_common_types = array();
 $attachment_common_types_parsed = array();
-session_register('attachment_common_types');
-session_register('attachment_common_types_parsed');
+sqsession_register($attachment_common_types, 'attachment_common_types');
+sqsession_register($attachment_common_types_parsed, 'attachment_common_types_parsed');
 
 $debug = false;
-if (isset($HTTP_SERVER_VARS['HTTP_ACCEPT']) &&
-    !isset($attachment_common_types_parsed[$HTTP_SERVER_VARS['HTTP_ACCEPT']]))
-    attachment_common_parse($HTTP_SERVER_VARS['HTTP_ACCEPT'], $debug);
-if (isset($HTTP_ACCEPT) &&
-    !isset($attachment_common_types_parsed[$HTTP_ACCEPT]))
-    attachment_common_parse($HTTP_ACCEPT, $debug);
 
+if (isset($_SERVER['HTTP_ACCEPT']) &&
+    !isset($attachment_common_types_parsed[$_SERVER['HTTP_ACCEPT']])) {
+    attachment_common_parse($_SERVER['HTTP_ACCEPT'], $debug);
+}
+if (isset($_SERVER['HTTP_ACCEPT']) &&
+    !isset($attachment_common_types_parsed[$_SERVER['HTTP_ACCEPT']])) {
+    attachment_common_parse($_SERVER['HTTP_ACCEPT'], $debug);
+}
 
 /* Complete autodetection of Javascript. */
 $javascript_setting = getPref
@@ -154,7 +170,8 @@ if(isset($rcptemail)) {
     $redirect_url = 'webmail.php';
 }
 
-/* Send them off to the appropriate page. */
+/* Write session data and send them off to the appropriate page. */
+session_write_close();
 header("Location: $redirect_url");
 
 /* --------------------- end main ----------------------- */
@@ -174,6 +191,7 @@ function attachment_common_parse($str, $debug) {
             $attachment_common_types[$val] = true;
         }
     }
+    $_SESSION['attachment_common_types'] = $attachment_common_types;
 }
 
 
