@@ -8,7 +8,7 @@
  *
  *  Cleans up after the user. Resets cookies and terminates session.
  *
- * $Id: signout.php,v 1.48 2002/01/28 18:33:33 kink Exp $
+ * $Id: signout.php,v 1.53.2.2 2002/10/02 05:57:33 jangliss Exp $
  */
 
 require_once('../src/validate.php');
@@ -17,32 +17,34 @@ require_once('../functions/plugin.php');
 require_once('../functions/strings.php');
 
 /* Erase any lingering attachments */
-if (! isset($attachments)) {
-    $attachments = array();
-}
-$hashed_attachment_dir = getHashedDir($username, $attachment_dir);
-foreach ($attachments as $info) {
-    $attached_file = "$hashed_attachment_dir/$info[localfilename]";
-    if (file_exists($attached_file)) {
-        unlink($attached_file);
+if (isset($attachments) && is_array($attachments) 
+    && sizeof($attachments)){
+    $hashed_attachment_dir = getHashedDir($username, $attachment_dir);
+    foreach ($attachments as $info) {
+        $attached_file = "$hashed_attachment_dir/$info[localfilename]";
+        if (file_exists($attached_file)) {
+            unlink($attached_file);
+        }
     }
 }
 
 if (!isset($frame_top)) {
-     $frame_top = '_top';
+    $frame_top = '_top';
 }
 
 /* If a user hits reload on the last page, $base_uri isn't set
  * because it was deleted with the session. */
-if (! isset($base_uri)) {
-    ereg ('(^.*/)[^/]+/[^/]+$', $PHP_SELF, $regs);
-    $base_uri = $regs[1];
+if (!isset($_SESSION['base_uri'])) {
+    if (!function_exists('sqm_baseuri')){
+        require_once('../functions/display_messages.php');
+    }
+    $base_uri = sqm_baseuri();
+} else {
+    $base_uri = $_SESSION['base_uri'];
 }
 
 do_hook('logout');
-setcookie('username', '', 0, $base_uri);
-setcookie('key', '', 0, $base_uri);
-session_destroy();
+sqsession_destroy();
 
 if ($signout_page) {
     header('Status: 303 See Other');
@@ -88,4 +90,4 @@ CELLPADDING="2" ALIGN="CENTER">
   </TR>
 </TABLE>
 </BODY>
-</HTML>
\ No newline at end of file
+</HTML>
